@@ -2,7 +2,6 @@
 // Name:        wx/osx/dcmemory.h
 // Purpose:     wxMemoryDC class
 // Author:      Stefan Csomor
-// Modified by:
 // Created:     1998-01-01
 // Copyright:   (c) Stefan Csomor
 // Licence:     wxWindows licence
@@ -22,14 +21,14 @@ public:
 
     virtual ~wxMemoryDCImpl();
 
-    virtual void DoGetSize( int *width, int *height ) const wxOVERRIDE;
-    virtual wxBitmap DoGetAsBitmap(const wxRect *subrect) const wxOVERRIDE
-       { return subrect == NULL ? GetSelectedBitmap() : GetSelectedBitmap().GetSubBitmap(*subrect); }
-    virtual void DoSelect(const wxBitmap& bitmap) wxOVERRIDE;
+    virtual void DoGetSize( int *width, int *height ) const override;
+    virtual wxBitmap DoGetAsBitmap(const wxRect *subrect) const override
+       { return subrect == nullptr ? GetSelectedBitmap() : GetSelectedBitmap().GetSubBitmap(*subrect); }
+    virtual void DoSelect(const wxBitmap& bitmap) override;
 
-    virtual const wxBitmap& GetSelectedBitmap() const wxOVERRIDE
+    virtual const wxBitmap& GetSelectedBitmap() const override
         { return m_selected; }
-    virtual wxBitmap& GetSelectedBitmap() wxOVERRIDE
+    virtual wxBitmap& GetSelectedBitmap() override
         { return m_selected; }
 
 private:
