@@ -48,9 +48,6 @@ public:
 
     /**
         The name of the function where the log record was generated.
-
-        This field may be @NULL if the compiler doesn't support @c \__FUNCTION__
-        (but most modern compilers do).
      */
     const char *func;
 
@@ -115,6 +112,9 @@ public:
         [7872] d:\testApp\src\testApp.cpp(85) : *** Application started ***
     @endverbatim
 
+    See wxLogFormatterNone for a trivial version of this class not doing any
+    formatting,
+
     @library{wxbase}
     @category{logging}
 
@@ -195,6 +195,31 @@ protected:
 };
 
 
+/**
+    Specialized formatter not formatting the messages at all.
+
+    This class can be used to make wxLog log just the messages themselves,
+    without any time stamps or prefixes indicating their severity.
+
+    Example of using it:
+
+    @code
+    wxLog* logger = wxLog::GetActiveTarget();
+    delete logger->SetFormatter(new wxLogFormatterNone{});
+
+    // Log messages won't have time stamps or "Error:", "Warning:" etc
+    // prefixes any more.
+    @endcode
+
+    @since 3.3.0
+*/
+class wxLogFormatterNone : public wxLogFormatter
+{
+public:
+    /// Trivial default constructor.
+    wxLogFormatterNone();
+};
+
 /**
     @class wxLog
 
@@ -306,10 +331,6 @@ public:
         active log target is set to @NULL a new default log target will be
         created when logging occurs.
 
-        @note The logging system will take ownership of the target you pass
-        in here. However, it is your responsibility to delete the target you
-        are replacing (i.e., the return value of this function).
-
         @see SetThreadActiveTarget()
     */
     static wxLog* SetActiveTarget(wxLog* logtarget);
@@ -348,6 +369,10 @@ public:
         When it is called from the other threads it simply calls Flush() on the
         currently active log target, so it mostly makes sense to do this if a
         thread has its own logger set with SetThreadActiveTarget().
+
+        Note that when using the default log target, this method is called
+        automatically before showing any modal dialog, in order to prevent
+        showing several modal dialogs one after another.
     */
     static void FlushActive();
 
@@ -388,6 +413,9 @@ public:
         All messages at levels strictly greater than the value returned by this
         function are not logged at all.
 
+        Note that this function is *not* thread-safe and should only be used
+        from the main thread.
+
         @see SetLogLevel(), IsLevelEnabled()
     */
     static wxLogLevel GetLogLevel();
@@ -399,6 +427,9 @@ public:
         @a level is less than or equal to the maximal log level enabled for the
         given @a component.
 
+        Note that this function is *not* thread-safe and should only be used
+        from the main thread.
+
         @see IsEnabled(), SetLogLevel(), GetLogLevel(), SetComponentLevel()
 
         @since 2.9.1
@@ -431,6 +462,10 @@ public:
         Specifies that log messages with level greater (numerically) than
         @a logLevel should be ignored and not sent to the active log target.
 
+        Note that this function is *not* thread-safe and can only be called
+        from the main thread. To temporarily disable logging from the other
+        threads, use wxLogNull, which is safe to use from them.
+
         @see SetComponentLevel()
     */
     static void SetLogLevel(wxLogLevel logLevel);
@@ -450,6 +485,9 @@ public:
         Calling this function with @false argument disables all log messages
         for the current thread.
 
+        This function is thread-safe and can be called by multiple threads
+        concurrently.
+
         @see wxLogNull, IsEnabled()
 
         @return
@@ -461,6 +499,9 @@ public:
     /**
         Returns true if logging is enabled at all now.
 
+        This function is thread-safe and can be called by multiple threads
+        concurrently.
+
         @see IsLevelEnabled(), EnableLogging()
      */
     static bool IsEnabled();
@@ -482,6 +523,11 @@ public:
 
         Notice that the current time stamp is only used by the default log
         formatter and custom formatters may ignore this format.
+
+        The default time stamp is `%X`, i.e. locale-dependent time
+        representation.
+
+        @see SetTimestamp()
     */
     static const wxString& GetTimestamp();
 
@@ -495,6 +541,11 @@ public:
         formatter and custom formatters may ignore this format. You can also
         define a custom wxLogFormatter to customize the time stamp handling
         beyond changing its format.
+
+        In addition to calling this function explicitly, it can also be called
+        implicitly by wxWidgets if `WXLOG_TIME_FORMAT` environment variable is
+        set, see @ref overview_envvars "overview of the environment variables"
+        affecting wxWidgets programs.
     */
     static void SetTimestamp(const wxString& format);
 
@@ -663,7 +714,7 @@ protected:
 
     // don't delete logChain directly as this would leave a dangling
     // pointer as active log target, use SetActiveTarget() instead
-    delete wxLog::SetActiveTarget(...something else or NULL...);
+    delete wxLog::SetActiveTarget(...something else or nullptr...);
     @endcode
 
     @library{wxbase}
@@ -776,8 +827,9 @@ public:
 
     This class can be used to redirect the log messages to a C++ stream.
 
-    Please note that this class is only available if wxWidgets was compiled with
-    the standard iostream library support (@c wxUSE_STD_IOSTREAM must be on).
+    @note
+        This class is not available if `wxUSE_STD_IOSTREAM` is set to 0 (which
+        is done by `--disable-std_iostreams` option when using configure).
 
     @library{wxbase}
     @category{logging}
@@ -806,7 +858,7 @@ public:
             to the character set given by @a conv, that message will be
             silently ignored, i.e. it will not be written at all.
     */
-    wxLogStream(std::ostream *ostr = NULL,
+    wxLogStream(std::ostream *ostr = nullptr,
                 const wxMBConv &conv = wxConvWhateverWorks);
 };
 
@@ -848,7 +900,7 @@ public:
             to the character set given by @a conv, that message will be
             silently ignored, i.e. it will not be written at all.
     */
-    wxLogStderr(FILE *fp = NULL,
+    wxLogStderr(FILE *fp = nullptr,
                 const wxMBConv &conv = wxConvWhateverWorks);
 };
 
@@ -877,6 +929,18 @@ public:
     */
     wxLogBuffer();
 
+    /**
+        Clear all the messages in the buffer.
+
+        This can be done to prevent them from being flushed by the next call to
+        Flush(), which happens implicitly if this logger ceases to be the
+        active logger after a call to wxLog::SetActiveTarget() with a different
+        log target.
+
+        @since 3.3.0
+    */
+    void Clear();
+
     /**
         Shows all the messages collected so far to the user (using a message box in the
         GUI applications or by printing them out to the console in text mode) and
@@ -894,6 +958,65 @@ public:
 };
 
 
+/**
+    @class wxLogCollector
+
+    Allows to collect all log messages into a string instead of showing them.
+
+    This class is supposed to be used as a local variable and collects all the
+    messages logged during its lifetime instead of showing them as usual, e.g.
+
+    @code
+    void Foo()
+    {
+        wxLogCollector collectLogs;
+
+        // Call some function that can log error messages, e.g. try to create a
+        // new directory. Without wxLogCollector a failure here would show
+        // errors to the user.
+        if ( !wxFileName::Mkdir("/some/path", wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL) )
+        {
+            // Instead, we can report them here as we see fit, e.g. write them
+            // to a log file or process them in some other way.
+            wxFprintf(logFile, "Creating directory failed: %s",
+                      collectLogs.GetMessages());
+        }
+    }
+    @endcode
+
+    Note that because this class uses wxLog::SetActiveTarget() to temporarily
+    switch the active log target to wxLogBuffer, you need to ensure that the
+    log target doesn't change while it is alive (in the simplest case by just
+    avoiding to change it at all).
+
+    @since 3.3.0
+*/
+class wxLogCollector
+{
+public:
+    /**
+        Constructor overrides active log target to collect messages.
+    */
+    wxLogCollector();
+
+    /**
+        Get all the collected messages.
+
+        The returned string may be empty but if it isn't, it contains the
+        trailing new line (and may also contain more new lines inside it if
+        multiple messages were logged).
+
+        Note that the messages here contain just the messages, without any time
+        stamps or log level prefixes.
+    */
+    const wxString& GetMessages() const;
+
+    /**
+        Destructor restores the previously active log target.
+    */
+    ~wxLogCollector();
+};
+
 
 /**
     @class wxLogNull
@@ -939,6 +1062,10 @@ public:
       }
     @endcode
 
+    This class is thread-safe and can be used from both the main and the
+    backgrounds threads.
+
+    @see wxLogCollector
 
     @library{wxbase}
     @category{logging}
@@ -1431,10 +1558,12 @@ void wxVLogError(const char* formatString, va_list argPtr);
     do the same thing for log messages of any level, and not just the tracing
     ones.
 
-    Like wxLogDebug(), trace functions only do something in debug builds and
-    expand to nothing in the release one. The reason for making it a separate
-    function is that usually there are a lot of trace messages, so it might
-    make sense to separate them from other debug messages.
+    Like wxLogDebug(), trace functions are disabled at compile time if
+    wxWidgets is compiled without debugging support, i.e. with `wxDEBUG_LEVEL`
+    set to 0 see @ref overview_debugging "Debugging overview" for more details).
+    The reason for having a separate function for tracing messages is that
+    usually there are a lot of them and so it may be useful to separate them
+    from the other debug messages.
 
     Trace messages can be separated into different categories; these functions in facts
     only log the message if the given @a mask is currently enabled in wxLog.
@@ -1493,9 +1622,13 @@ void wxVLogTrace(wxTraceMask mask, const char* formatString, va_list argPtr);
 /** @addtogroup group_funcmacro_log */
 ///@{
 /**
-    The right functions for debug output. They only do something in debug mode
-    (when the preprocessor symbol @c \__WXDEBUG__ is defined) and expand to
-    nothing in release mode (otherwise).
+    The function to use for debugging output.
+
+    In addition to not producing any output if the current log level is not
+    high enough, just as all the other logging function, this function does
+    nothing at all, and is not even present in the final executable code, if
+    wxWidgets was compiled without debugging support, i.e. `wxDEBUG_LEVEL` is 0
+    (see @ref overview_debugging "Debugging overview" for more details).
 
     @header{wx/log.h}
 */
