@@ -235,7 +235,16 @@ struct wxPGPaintData
     @{
 */
 
-enum class wxPGPropertyFlags : int
+/**
+    Strongly typed enums containing properties flags.
+
+    Note that this replaces wxPGPropertyFlags enum used in previous wxWidgets
+    versions which defined the same flags using `wxPG_PROP_XXX` naming
+    convention.
+
+    @since 3.3.1
+ */
+enum class wxPGFlags : int
 {
     /** No flags.
         @hideinitializer
@@ -565,11 +574,12 @@ enum class wxPGPropertyFlags : int
 
     Like wxStringProperty, but has a button that triggers a small text editor
     dialog. Note that in long string values, some control characters are
-    escaped: tab is represented by "\t", line break by "\n", carriage return
-    by "\r" and backslash character by "\\". If another character is preceded
-    by backslash, the backslash is skipped.
+    escaped: tab is represented by `"\t"`, line break by `"\n"`, carriage return
+    by `"\r"` and backslash characters are doubled. If another character is
+    preceded by backslash, the backslash is skipped.
+
     Note also that depending on the system (port), some sequences of special
-    characters, like e.g. "\r\n", can be interpreted and presented in
+    characters, like e.g. `"\r\n"`, can be interpreted and presented in
     a different way in the editor and therefore such sequences may not be
     the same before and after the edition.
 
@@ -1272,20 +1282,11 @@ public:
     */
     int AddChoice( const wxString& label, int value = wxPG_INVALID_VALUE );
 
-    /**
-        Adds a private child property.
-
-        @deprecated Use AddPrivateChild() instead.
-
-        @see AddPrivateChild()
-    */
-    void AddChild( wxPGProperty* prop );
-
     /**
         Adds a private child property. If you use this instead of
         wxPropertyGridInterface::Insert() or
         wxPropertyGridInterface::AppendIn(), then property's parental
-        type will automatically be set up to wxPGPropertyFlags::Aggregate.
+        type will automatically be set up to wxPGFlags::Aggregate.
         In other words, all properties of this property will become private.
     */
     void AddPrivateChild( wxPGProperty* prop );
@@ -1331,11 +1332,11 @@ public:
                  intended almost exclusively for internal use. So, for
                  example, if you want to disable a property, call
                  @code Enable(false) @endcode instead of setting
-                 wxPGPropertyFlags::Disabled flag.
+                 wxPGFlags::Disabled flag.
 
         @see HasFlag(), GetFlags()
     */
-    void ChangeFlag( wxPGPropertyFlags flag, bool set );
+    void ChangeFlag( wxPGFlags flag, bool set );
 
     /**
         Deletes children of the property.
@@ -1549,12 +1550,12 @@ public:
     const wxString& GetHelpString() const;
 
     /** Gets flags as a'|' delimited string. Note that flag names are not
-        prepended with 'wxPGPropertyFlags'.
+        prepended with 'wxPGFlags'.
 
         @param flagsMask
         String will only be made to include flags combined by this parameter.
     */
-    wxString GetFlagsAsString(wxPGPropertyFlags flagsMask) const;
+    wxString GetFlagsAsString(wxPGFlags flagsMask) const;
 
     /**
         Returns position in parent's array.
@@ -1657,12 +1658,12 @@ public:
 
         @see propgrid_propflags
     */
-    bool HasFlag(wxPGPropertyFlags flag) const;
+    bool HasFlag(wxPGFlags flag) const;
 
     /**
         Returns @true if property has all given flags set.
     */
-    bool HasFlagsExact(wxPGPropertyFlags flags) const;
+    bool HasFlagsExact(wxPGFlags flags) const;
 
     /**
         Returns @true if property has even one visible child.
@@ -1902,7 +1903,7 @@ public:
     void SetExpanded( bool expanded );
 
     /** Sets flags from a '|' delimited string. Note that flag names are not
-        prepended with 'wxPGPropertyFlags'.
+        prepended with 'wxPGFlags'.
     */
     void SetFlagsFromString( const wxString& str );
 
@@ -1912,7 +1913,7 @@ public:
 
         @see ChangeFlag()
     */
-    void SetFlagRecursively( wxPGPropertyFlags flag, bool set );
+    void SetFlagRecursively( wxPGFlags flag, bool set );
 
     /**
         Sets property's help string, which is shown, for example, in
@@ -1961,14 +1962,14 @@ public:
         Changes what sort of parent this property is for its children.
 
         @param flag
-            Use one of the following values: wxPGPropertyFlags::MiscParent (for
-            generic parents), wxPGPropertyFlags::Category (for categories), or
-            wxPGPropertyFlags::Aggregate (for derived property classes with
+            Use one of the following values: wxPGFlags::MiscParent (for
+            generic parents), wxPGFlags::Category (for categories), or
+            wxPGFlags::Aggregate (for derived property classes with
             private children).
 
         @remarks You generally do not need to call this function.
     */
-    void SetParentalType(wxPGPropertyFlags flag);
+    void SetParentalType(wxPGFlags flag);
 
     /**
         Sets property's text colour.
@@ -2147,21 +2148,21 @@ protected:
                           const wxPGCell& preparedCell,
                           const wxPGCell& srcData,
                           wxPGCellData* unmodCellData,
-                          wxPGPropertyFlags ignoreWithFlags,
+                          wxPGFlags ignoreWithFlags,
                           bool recursively );
 
     /**
         Clear cells associated with property.
 
         @param ignoreWithFlags
-            Cells will not be cleared for properties having these flags set. 
+            Cells will not be cleared for properties having these flags set.
 
         @param recursively
             If @true, apply this operation recursively in child properties.
 
         @since 3.1.0
     */
-    void ClearCells(wxPGPropertyFlags ignoreWithFlags, bool recursively);
+    void ClearCells(wxPGFlags ignoreWithFlags, bool recursively);
 
     /**
         Makes sure m_cells has size of column+1 (or more).
