@@ -341,21 +341,21 @@
     @section string_index Index of the member groups
 
     Links for quick access to the various categories of wxString functions:
-    - @ref_member_group{ctor, Constructors and assignment operators}
-    - @ref_member_group{length, Length functions}
-    - @ref_member_group{ch_access, Character access functions}
-    - @ref_member_group{conv, Conversions functions}
-    - @ref_member_group{concat, Concatenation functions}
-    - @ref_member_group{cmp, Comparison functions}
-    - @ref_member_group{substring, Substring extraction functions}
-    - @ref_member_group{caseconv, Case conversion functions}
-    - @ref_member_group{search, Searching and replacing functions}
-    - @ref_member_group{numconv, Conversion to numbers functions}
-    - @ref_member_group{fmt, Formatting and printing functions}
-    - @ref_member_group{mem, Memory management functions}
-    - @ref_member_group{misc, Miscellaneous functions}
-    - @ref_member_group{iter, Iterator interface functions}
-    - @ref_member_group{stl, STL interface functions}
+    - @ref_member_group{string_ctor, Constructors and assignment operators}
+    - @ref_member_group{string_length, Length functions}
+    - @ref_member_group{string_ch_access, Character access functions}
+    - @ref_member_group{string_convs, Conversions functions}
+    - @ref_member_group{string_concat, Concatenation functions}
+    - @ref_member_group{string_cmp, Comparison functions}
+    - @ref_member_group{string_substring, Substring extraction functions}
+    - @ref_member_group{string_caseconv, Case conversion functions}
+    - @ref_member_group{string_search, Searching and replacing functions}
+    - @ref_member_group{string_numconv, Conversion to numbers functions}
+    - @ref_member_group{string_fmt, Formatting and printing functions}
+    - @ref_member_group{string_mem, Memory management functions}
+    - @ref_member_group{string_misc, Miscellaneous functions}
+    - @ref_member_group{string_iter, Iterator interface functions}
+    - @ref_member_group{string_stl, STL interface functions}
 
 
     @library{wxbase}
@@ -388,7 +388,7 @@ public:
 
 
     /**
-        @member_group_name{ctor, Constructors and assignment operators}
+        @member_group_name{string_ctor, Constructors and assignment operators}
 
         A string may be constructed either from a C string, (some number of copies of)
         a single character or a wide (Unicode) string. For all constructors (except the
@@ -532,7 +532,7 @@ public:
 
 
     /**
-        @member_group_name{length, String length}
+        @member_group_name{string_length, String length}
 
         These functions return the string length and/or check whether the string
         is empty.
@@ -579,7 +579,7 @@ public:
 
 
     /**
-        @member_group_name{ch_access, Character access}
+        @member_group_name{string_ch_access, Character access}
 
         Many functions below take a character index in the string.
         As with C strings and arrays, the indices start from 0, so the first character
@@ -640,7 +640,7 @@ public:
 
 
     /**
-        @member_group_name{conv, Conversions}
+        @member_group_name{string_convs, Conversions}
 
         This section contains both implicit and explicit conversions to C style
         strings. Although implicit conversion is quite convenient, you are advised
@@ -861,7 +861,7 @@ public:
 
 
     /**
-        @member_group_name{concat, Concatenation}
+        @member_group_name{string_concat, Concatenation}
 
         Almost anything may be concatenated (appended to) with a string!
 
@@ -951,7 +951,7 @@ public:
 
 
     /**
-        @member_group_name{cmp, Comparison}
+        @member_group_name{string_cmp, Comparison}
 
         The default comparison function Cmp() is case-sensitive and so is the default
         version of IsSameAs(). For case insensitive comparisons you should use CmpNoCase()
@@ -1091,7 +1091,7 @@ public:
 
 
     /**
-        @member_group_name{substring, Substring extraction}
+        @member_group_name{string_substring, Substring extraction}
 
         These functions allow you to extract a substring from the string. The
         original string is not modified and the function returns the extracted
@@ -1179,7 +1179,7 @@ public:
 
 
     /**
-        @member_group_name{caseconv, Case conversion}
+        @member_group_name{string_caseconv, Case conversion}
 
         The MakeXXX() variants modify the string in place, while the other functions
         return a new string which contains the original text converted to the upper or
@@ -1256,7 +1256,7 @@ public:
 
 
     /**
-        @member_group_name{search, Searching and replacing}
+        @member_group_name{string_search, Searching and replacing}
 
         These functions replace the standard @c strchr() and @c strstr()
         functions.
@@ -1314,7 +1314,7 @@ public:
 
 
     /**
-        @member_group_name{numconv, Conversion to numbers}
+        @member_group_name{string_numconv, Conversion to numbers}
 
         The string provides functions for conversion to signed and unsigned integer and
         floating point numbers.
@@ -1493,7 +1493,7 @@ public:
 
 
     /**
-        @member_group_name{fmt, Formatting and printing}
+        @member_group_name{string_fmt, Formatting and printing}
 
         Both formatted versions (Printf/() and stream-like insertion operators
         exist (for basic types only).
@@ -1536,7 +1536,7 @@ public:
 
 
     /**
-        @member_group_name{mem, Memory management}
+        @member_group_name{string_mem, Memory management}
 
         The following are "advanced" functions and they will be needed rarely.
         Alloc() and Shrink() are only interesting for optimization purposes.
@@ -1627,7 +1627,7 @@ public:
 
 
     /**
-        @member_group_name{misc, Miscellaneous}
+        @member_group_name{string_misc, Miscellaneous}
 
         Miscellaneous other string functions.
     */
@@ -1735,7 +1735,7 @@ public:
 
 
     /**
-        @member_group_name{iter, Iterator interface}
+        @member_group_name{string_iter, Iterator interface}
 
         These methods return iterators to the beginning or end of the string.
 
@@ -1763,7 +1763,7 @@ public:
 
 
     /**
-        @member_group_name{stl, STL interface}
+        @member_group_name{string_stl, STL interface}
 
         The supported STL functions are listed here.
 
