@@ -28,6 +28,7 @@
 #endif
 
 #include "wx/calctrl.h"
+#include "wx/datectrl.h"
 #include "wx/intl.h"
 #include "wx/file.h"
 #include "wx/grid.h"
@@ -36,6 +37,7 @@
 #include "wx/numformatter.h"
 #include "wx/platinfo.h"
 #include "wx/spinctrl.h"
+#include "wx/timectrl.h"
 #include "wx/translation.h"
 #include "wx/uilocale.h"
 
@@ -399,18 +401,33 @@ MyFrame::MyFrame()
 
     // create some controls affected by the locale
 
+    const int border = wxSizerFlags::GetDefaultBorder();
+    auto* const sizerInput = new wxFlexGridSizer(2, wxSize(border, border));
+    sizerInput->AddGrowableCol(1);
+
     // this demonstrates RTL layout mirroring for Arabic locales and using
     // locale-specific decimal separator in wxSpinCtrlDouble.
-    wxSizer *sizer = new wxBoxSizer(wxHORIZONTAL);
-    sizer->Add(new wxStaticText(panel, wxID_ANY, _("Numeric input:")),
-               wxSizerFlags().Center().Border());
+    sizerInput->Add(new wxStaticText(panel, wxID_ANY, _("Numeric input:")),
+                    wxSizerFlags().CenterVertical().Right());
 
     wxSpinCtrlDouble* const spin = new wxSpinCtrlDouble(panel, wxID_ANY);
     spin->SetDigits(2);
     spin->SetValue(12.34);
-    sizer->Add(spin, wxSizerFlags().Center().Border());
+    sizerInput->Add(spin, wxSizerFlags().CenterVertical().Expand());
 
-    topSizer->Add(sizer, wxSizerFlags().Center());
+    // this one demonstrates the locale-specific date format
+    sizerInput->Add(new wxStaticText(panel, wxID_ANY, _("Date input:")),
+                    wxSizerFlags().CenterVertical().Right());
+    sizerInput->Add(new wxDatePickerCtrl(panel, wxID_ANY),
+                    wxSizerFlags().CenterVertical().Expand());
+
+    // and this one does the same for time format
+    sizerInput->Add(new wxStaticText(panel, wxID_ANY, _("Time input:")),
+                    wxSizerFlags().CenterVertical().Right());
+    sizerInput->Add(new wxTimePickerCtrl(panel, wxID_ANY),
+                    wxSizerFlags().CenterVertical().Expand());
+
+    topSizer->Add(sizerInput, wxSizerFlags().Center());
 
     // show that week days and months names are translated too
     topSizer->Add(new wxCalendarCtrl(panel, wxID_ANY),
