@@ -2,7 +2,6 @@
 // Name:        samples/richtext/richtext.cpp
 // Purpose:     wxWidgets rich text editor sample
 // Author:      Julian Smart
-// Modified by:
 // Created:     2005-10-02
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
@@ -91,15 +90,15 @@ public:
     {
     }
 
-    virtual bool CanEditProperties(wxRichTextField* WXUNUSED(obj)) const wxOVERRIDE { return true; }
-    virtual bool EditProperties(wxRichTextField* WXUNUSED(obj), wxWindow* WXUNUSED(parent), wxRichTextBuffer* WXUNUSED(buffer)) wxOVERRIDE
+    virtual bool CanEditProperties(wxRichTextField* WXUNUSED(obj)) const override { return true; }
+    virtual bool EditProperties(wxRichTextField* WXUNUSED(obj), wxWindow* WXUNUSED(parent), wxRichTextBuffer* WXUNUSED(buffer)) override
     {
         wxString label = GetLabel();
         wxMessageBox(wxString::Format("Editing %s", label));
         return true;
     }
 
-    virtual wxString GetPropertiesMenuLabel(wxRichTextField* WXUNUSED(obj)) const wxOVERRIDE
+    virtual wxString GetPropertiesMenuLabel(wxRichTextField* WXUNUSED(obj)) const override
     {
         return GetLabel();
     }
@@ -114,7 +113,7 @@ public:
     {
     }
 
-    virtual bool UpdateField(wxRichTextBuffer* buffer, wxRichTextField* obj) wxOVERRIDE
+    virtual bool UpdateField(wxRichTextBuffer* buffer, wxRichTextField* obj) override
     {
         if (buffer)
         {
@@ -166,19 +165,19 @@ public:
         Prepares the content just before insertion (or after buffer reset). Called by the same function in wxRichTextBuffer.
         Currently is only called if undo mode is on.
     */
-    virtual void PrepareContent(wxRichTextParagraphLayoutBox& container) wxOVERRIDE;
+    virtual void PrepareContent(wxRichTextParagraphLayoutBox& container) override;
 
     /**
         Can we delete this range?
         Sends an event to the control.
     */
-    virtual bool CanDeleteRange(wxRichTextParagraphLayoutBox& container, const wxRichTextRange& range) const wxOVERRIDE;
+    virtual bool CanDeleteRange(wxRichTextParagraphLayoutBox& container, const wxRichTextRange& range) const override;
 
     /**
         Can we insert content at this position?
         Sends an event to the control.
     */
-    virtual bool CanInsertContent(wxRichTextParagraphLayoutBox& container, long pos) const wxOVERRIDE;
+    virtual bool CanInsertContent(wxRichTextParagraphLayoutBox& container, long pos) const override;
 
     /**
         Finds a table,  either selected or near the cursor
@@ -204,8 +203,8 @@ public:
     // this one is called on application startup and is a good place for the app
     // initialization (doing it here and not in the ctor allows to have an error
     // return: if OnInit() returns false, the application terminates)
-    virtual bool OnInit() wxOVERRIDE;
-    virtual int OnExit() wxOVERRIDE;
+    virtual bool OnInit() override;
+    virtual int OnExit() override;
 
     void CreateStyles();
 
@@ -315,7 +314,7 @@ public:
 protected:
 
     // Forward command events to the current rich text control, if any
-    bool ProcessEvent(wxEvent& event) wxOVERRIDE;
+    bool ProcessEvent(wxEvent& event) override;
 
     // Write text
     void WriteInitialText();
@@ -755,9 +754,9 @@ void MyApp::CreateStyles()
 // frame constructor
 MyFrame::MyFrame(const wxString& title, wxWindowID id, const wxPoint& pos,
         const wxSize& size, long style)
-       : wxFrame(NULL, id, title, pos, size, style)
+       : wxFrame(nullptr, id, title, pos, size, style)
 {
-    m_richTextCtrl = NULL;
+    m_richTextCtrl = nullptr;
 
 #ifdef __WXMAC__
     SetWindowVariant(wxWINDOW_VARIANT_SMALL);
@@ -1204,7 +1203,7 @@ void MyFrame::WriteInitialText()
 
         r.WriteText("This is a text box. Just testing! Once more unto the breach, dear friends, once more...");
 
-        r.SetFocusObject(NULL); // Set the focus back to the main buffer
+        r.SetFocusObject(nullptr); // Set the focus back to the main buffer
         r.SetInsertionPointEnd();
     }
 #endif
@@ -1263,7 +1262,7 @@ void MyFrame::WriteInitialText()
         cell->Clear();
         r.WriteText("This cell spans 2 columns and 3 rows");
 
-        r.SetFocusObject(NULL); // Set the focus back to the main buffer
+        r.SetFocusObject(nullptr); // Set the focus back to the main buffer
         r.SetInsertionPointEnd();
     }
 #endif
@@ -1345,7 +1344,7 @@ bool MyFrame::ProcessEvent(wxEvent& event)
                 focusWin = m_richTextCtrl;
             if (focusWin && focusWin->GetEventHandler()->ProcessEvent(event))
             {
-                //s_command = NULL;
+                //s_command = nullptr;
                 s_eventType = 0;
                 s_id = 0;
                 return true;
@@ -1769,7 +1768,7 @@ void MyFrame::OnReload(wxCommandEvent& WXUNUSED(event))
 
 void MyFrame::OnViewHTML(wxCommandEvent& WXUNUSED(event))
 {
-    wxDialog dialog(this, wxID_ANY, _("HTML"), wxDefaultPosition, wxSize(500, 400), wxDEFAULT_DIALOG_STYLE);
+    wxDialog dialog(this, wxID_ANY, "HTML", wxDefaultPosition, wxSize(500, 400), wxDEFAULT_DIALOG_STYLE);
 
     wxBoxSizer* boxSizer = new wxBoxSizer(wxVERTICAL);
     dialog.SetSizer(boxSizer);
@@ -1815,7 +1814,7 @@ void MyFrame::OnViewHTML(wxCommandEvent& WXUNUSED(event))
 
 void MyFrame::OnSwitchStyleSheets(wxCommandEvent& WXUNUSED(event))
 {
-    static wxRichTextStyleSheet* gs_AlternateStyleSheet = NULL;
+    static wxRichTextStyleSheet* gs_AlternateStyleSheet = nullptr;
 
     wxRichTextStyleListCtrl *styleList = (wxRichTextStyleListCtrl*) FindWindow(ID_RICHTEXT_STYLE_LIST);
     wxRichTextStyleComboCtrl* styleCombo = (wxRichTextStyleComboCtrl*) FindWindow(ID_RICHTEXT_STYLE_COMBO);
@@ -1870,7 +1869,7 @@ void MyFrame::OnManageStyles(wxCommandEvent& WXUNUSED(event))
 
     int flags = wxRICHTEXT_ORGANISER_CREATE_STYLES|wxRICHTEXT_ORGANISER_EDIT_STYLES;
 
-    wxRichTextStyleOrganiserDialog dlg(flags, sheet, NULL, this, wxID_ANY, _("Style Manager"));
+    wxRichTextStyleOrganiserDialog dlg(flags, sheet, nullptr, this, wxID_ANY, _("Style Manager"));
     dlg.ShowModal();
 }
 
@@ -1946,7 +1945,7 @@ void MyFrame::OnRenumberList(wxCommandEvent& WXUNUSED(event))
     if (m_richTextCtrl->HasSelection())
     {
         wxRichTextRange range = m_richTextCtrl->GetSelectionRange();
-        m_richTextCtrl->NumberList(range, NULL, wxRICHTEXT_SETSTYLE_WITH_UNDO|wxRICHTEXT_SETSTYLE_RENUMBER);
+        m_richTextCtrl->NumberList(range, nullptr, wxRICHTEXT_SETSTYLE_WITH_UNDO|wxRICHTEXT_SETSTYLE_RENUMBER);
     }
 }
 
@@ -1955,7 +1954,7 @@ void MyFrame::OnPromoteList(wxCommandEvent& WXUNUSED(event))
     if (m_richTextCtrl->HasSelection())
     {
         wxRichTextRange range = m_richTextCtrl->GetSelectionRange();
-        m_richTextCtrl->PromoteList(1, range, NULL);
+        m_richTextCtrl->PromoteList(1, range, nullptr);
     }
 }
 
@@ -1964,7 +1963,7 @@ void MyFrame::OnDemoteList(wxCommandEvent& WXUNUSED(event))
     if (m_richTextCtrl->HasSelection())
     {
         wxRichTextRange range = m_richTextCtrl->GetSelectionRange();
-        m_richTextCtrl->PromoteList(-1, range, NULL);
+        m_richTextCtrl->PromoteList(-1, range, nullptr);
     }
 }
 
@@ -2029,7 +2028,7 @@ void MyFrame::OnTableDeleteRow(wxCommandEvent& WXUNUSED(event))
 
 void MyFrame::OnTableFocusedUpdateUI(wxUpdateUIEvent& event)
 {
-    event.Enable(m_richTextCtrl->FindTable() != NULL);
+    event.Enable(m_richTextCtrl->FindTable() != nullptr);
 }
 
 void MyFrame::OnTableHasCellsUpdateUI(wxUpdateUIEvent& event)
@@ -2224,37 +2223,37 @@ public:
     /**
         Returns @true if this object has virtual attributes that we can provide.
     */
-    virtual bool HasVirtualAttributes(wxRichTextObject* obj) const wxOVERRIDE;
+    virtual bool HasVirtualAttributes(wxRichTextObject* obj) const override;
 
     /**
         Provides virtual attributes that we can provide.
     */
-    virtual bool GetVirtualAttributes(wxRichTextAttr& attr, wxRichTextObject* obj) const wxOVERRIDE;
+    virtual bool GetVirtualAttributes(wxRichTextAttr& attr, wxRichTextObject* obj) const override;
 
     /**
         Gets the count for mixed virtual attributes for individual positions within the object.
         For example, individual characters within a text object may require special highlighting.
     */
-    virtual int GetVirtualSubobjectAttributesCount(wxRichTextObject* WXUNUSED(obj)) const wxOVERRIDE { return 0; }
+    virtual int GetVirtualSubobjectAttributesCount(wxRichTextObject* WXUNUSED(obj)) const override { return 0; }
 
     /**
         Gets the mixed virtual attributes for individual positions within the object.
         For example, individual characters within a text object may require special highlighting.
         Returns the number of virtual attributes found.
     */
-    virtual int GetVirtualSubobjectAttributes(wxRichTextObject* WXUNUSED(obj), wxArrayInt& WXUNUSED(positions), wxRichTextAttrArray& WXUNUSED(attributes)) const wxOVERRIDE  { return 0; }
+    virtual int GetVirtualSubobjectAttributes(wxRichTextObject* WXUNUSED(obj), wxArrayInt& WXUNUSED(positions), wxRichTextAttrArray& WXUNUSED(attributes)) const override  { return 0; }
 
     /**
         Do we have virtual text for this object? Virtual text allows an application
         to replace characters in an object for editing and display purposes, for example
         for highlighting special characters.
     */
-    virtual bool HasVirtualText(const wxRichTextPlainText* WXUNUSED(obj)) const wxOVERRIDE { return false; }
+    virtual bool HasVirtualText(const wxRichTextPlainText* WXUNUSED(obj)) const override { return false; }
 
     /**
         Gets the virtual text for this object.
     */
-    virtual bool GetVirtualText(const wxRichTextPlainText* WXUNUSED(obj), wxString& WXUNUSED(text)) const wxOVERRIDE { return false; }
+    virtual bool GetVirtualText(const wxRichTextPlainText* WXUNUSED(obj), wxString& WXUNUSED(text)) const override { return false; }
 
     wxColour    m_lockBackgroundColour;
 };
@@ -2323,5 +2322,5 @@ wxRichTextTable* MyRichTextCtrl::FindTable() const
         }
     }
 
-    return NULL;
+    return nullptr;
 }
