@@ -29,7 +29,6 @@
     #include "wx/log.h"
     #include "wx/utils.h"
     #include "wx/app.h"
-    #include "wx/hashmap.h"
     #include "wx/module.h"
 #endif // WX_PRECOMP
 
@@ -49,7 +48,6 @@
 #include "wx/scopedptr.h"
 #include "wx/apptrait.h"
 #include "wx/stdpaths.h"
-#include "wx/hashset.h"
 #include "wx/uilocale.h"
 
 #include "wx/private/localeset.h"
@@ -115,32 +113,26 @@ wxUint32 wxLanguageInfo::GetLCID() const
 
 const char* wxLanguageInfo::TrySetLocale() const
 {
-    wxString locale;
+    // Prefer to use the locale names instead of locale identifiers if
+    // supported, both at the OS level (LOCALE_SNAME) and by the CRT (check by
+    // calling setlocale()).
+    const char* const retloc = wxSetlocale(LC_ALL, GetCanonicalWithRegion());
+    if ( retloc )
+        return retloc;
 
+    // Fall back to LOCALE_SENGLANGUAGE
     const LCID lcid = GetLCID();
 
     wxChar buffer[256];
     buffer[0] = wxT('\0');
 
-    // Prefer to use the new (Vista and later) locale names instead of locale
-    // identifiers if supported, both at the OS level (LOCALE_SNAME) and by the
-    // CRT (check by calling setlocale()).
-    if ( wxGetWinVersion() >= wxWinVersion_Vista )
-    {
-        locale = GetCanonicalWithRegion();
-        const char* const retloc = wxSetlocale(LC_ALL, locale);
-        if ( retloc )
-            return retloc;
-        //else: fall back to LOCALE_SENGLANGUAGE
-    }
-
     if ( !::GetLocaleInfo(lcid, LOCALE_SENGLANGUAGE, buffer, WXSIZEOF(buffer)) )
     {
         wxLogLastError(wxT("GetLocaleInfo(LOCALE_SENGLANGUAGE)"));
-        return NULL;
+        return nullptr;
     }
 
-    locale = buffer;
+    wxString locale = buffer;
     if ( ::GetLocaleInfo(lcid, LOCALE_SENGCOUNTRY,
                         buffer, WXSIZEOF(buffer)) > 0 )
     {
@@ -187,13 +179,13 @@ static bool gs_languagesDBInitialized = false;
 
 const wxLanguageInfos& wxGetLanguageInfos()
 {
-    wxUILocale::CreateLanguagesDB();
+    wxUILocaleImpl::CreateLanguagesDB();
 
     return gs_languagesDB;
 }
 
 /*static*/
-void wxUILocale::CreateLanguagesDB()
+void wxUILocaleImpl::CreateLanguagesDB()
 {
     if (!gs_languagesDBInitialized)
     {
@@ -204,7 +196,7 @@ void wxUILocale::CreateLanguagesDB()
 }
 
 /*static*/
-void wxUILocale::DestroyLanguagesDB()
+void wxUILocaleImpl::DestroyLanguagesDB()
 {
     if (gs_languagesDBInitialized)
     {
@@ -216,7 +208,7 @@ void wxUILocale::DestroyLanguagesDB()
 /* static */
 void wxUILocale::AddLanguage(const wxLanguageInfo& info)
 {
-    CreateLanguagesDB();
+    wxUILocaleImpl::CreateLanguagesDB();
     gs_languagesDB.push_back(info);
 }
 
@@ -227,21 +219,21 @@ void wxUILocale::AddLanguage(const wxLanguageInfo& info)
 /*static*/
 void wxLocale::CreateLanguagesDB()
 {
-    wxUILocale::CreateLanguagesDB();
+    wxUILocaleImpl::CreateLanguagesDB();
 }
 
 /*static*/
 void wxLocale::DestroyLanguagesDB()
 {
-    wxUILocale::DestroyLanguagesDB();
+    wxUILocaleImpl::DestroyLanguagesDB();
 }
 
 void wxLocale::DoCommonInit()
 {
     m_language = wxLANGUAGE_UNKNOWN;
 
-    m_pszOldLocale = NULL;
-    m_pOldLocale = NULL;
+    m_pszOldLocale = nullptr;
+    m_pOldLocale = nullptr;
 
 #ifdef __WIN32__
     m_oldLCID = 0;
@@ -255,16 +247,8 @@ bool wxLocale::Init(const wxString& name,
                     const wxString& shortName,
                     const wxString& locale,
                     bool            bLoadDefault
-#if WXWIN_COMPATIBILITY_2_8
-                   ,bool            WXUNUSED_UNLESS_DEBUG(bConvertEncoding)
-#endif
                     )
 {
-#if WXWIN_COMPATIBILITY_2_8
-    wxASSERT_MSG( bConvertEncoding,
-                  wxS("wxLocale::Init with bConvertEncoding=false is no longer supported, add charset to your catalogs") );
-#endif
-
     wxString strName(name);
     wxString strShort(shortName);
 
@@ -332,7 +316,7 @@ bool wxLocale::Init(const wxString& name,
     // Under (non-Darwin) Unix wxUILocale already set the C locale, but under
     // the other platforms we still have to do it here.
 #if defined(__WIN32__) || defined(__WXOSX__)
-    ok = wxSetlocale(LC_ALL, szLocale) != NULL;
+    ok = wxSetlocale(LC_ALL, szLocale) != nullptr;
 #endif // __WIN32__
 
 #else
@@ -355,7 +339,7 @@ void wxLocale::DoInit(const wxString& name,
     m_language = language;
 
     // Store the current locale in order to be able to restore it in the dtor.
-    m_pszOldLocale = wxSetlocale(LC_ALL, NULL);
+    m_pszOldLocale = wxSetlocale(LC_ALL, nullptr);
     if ( m_pszOldLocale )
         m_pszOldLocale = wxStrdup(m_pszOldLocale);
 
@@ -396,7 +380,7 @@ bool wxLocale::DoCommonPostInit(bool success,
         // As we failed to change locale, there is no need to restore the
         // previous one: it's still valid.
         free(const_cast<char *>(m_pszOldLocale));
-        m_pszOldLocale = NULL;
+        m_pszOldLocale = nullptr;
 
         // continue nevertheless and try to load at least the translations for
         // this language
@@ -419,11 +403,6 @@ bool wxLocale::DoCommonPostInit(bool success,
 
 bool wxLocale::Init(int lang, int flags)
 {
-#if WXWIN_COMPATIBILITY_2_8
-    wxASSERT_MSG( !(flags & wxLOCALE_CONV_ENCODING),
-                  wxS("wxLOCALE_CONV_ENCODING is no longer supported, add charset to your catalogs") );
-#endif
-
     wxCHECK_MSG( lang != wxLANGUAGE_UNKNOWN, false,
                  wxS("Initializing unknown locale doesn't make sense, did you ")
                  wxS("mean to use wxLANGUAGE_DEFAULT perhaps?") );
@@ -433,7 +412,7 @@ bool wxLocale::Init(int lang, int flags)
     const wxLanguageInfo *info = GetLanguageInfo(lang);
 
     // Unknown language:
-    if (info == NULL)
+    if (info == nullptr)
     {
         // This could have happened because some concrete language has been
         // requested and we just don't know anything about it. In this case, we
@@ -486,7 +465,7 @@ bool wxLocale::Init(int lang, int flags)
     const char *retloc = lang == wxLANGUAGE_DEFAULT ? wxSetlocale(LC_ALL, "")
                                                     : info->TrySetLocale();
 
-#if wxUSE_UNICODE && (defined(__VISUALC__) || defined(__MINGW32__))
+#if defined(__VISUALC__) || defined(__MINGW32__)
     // VC++ setlocale() (also used by Mingw) can't set locale to languages that
     // can only be written using Unicode, therefore wxSetlocale() call fails
     // for such languages but we don't want to report it as an error -- so that
@@ -578,7 +557,7 @@ wxString wxLocale::GetSystemEncodingName()
         // the environment variables (in most cases this won't work, but I was
         // out of ideas)
         char* lang = getenv("LC_ALL");
-        char* dot = lang ? strchr(lang, '.') : NULL;
+        char* dot = lang ? strchr(lang, '.') : nullptr;
         if (!dot)
         {
             lang = getenv("LC_CTYPE");
@@ -642,6 +621,7 @@ wxFontEncoding wxLocale::GetSystemEncoding()
     case 65001:
         return wxFONTENCODING_UTF8;
     }
+    return wxFONTENCODING_SYSTEM;
 #elif defined(__WXMAC__)
     CFStringEncoding encoding = 0;
     encoding = CFStringGetSystemEncoding();
@@ -652,18 +632,6 @@ wxFontEncoding wxLocale::GetSystemEncoding()
     {
         wxFontEncoding enc = wxFontMapperBase::GetEncodingFromName(encname);
 
-        // on some modern Linux systems (RedHat 8) the default system locale
-        // is UTF8 -- but it isn't supported by wxGTK1 in ANSI build at all so
-        // don't even try to use it in this case
-#if !wxUSE_UNICODE && \
-        ((defined(__WXGTK__) && !defined(__WXGTK20__)) || defined(__WXMOTIF__))
-        if (enc == wxFONTENCODING_UTF8)
-        {
-            // the most similar supported encoding...
-            enc = wxFONTENCODING_ISO8859_1;
-        }
-#endif // !wxUSE_UNICODE
-
         // GetEncodingFromName() returns wxFONTENCODING_DEFAULT for C locale
         // (a.k.a. US-ASCII) which is arguably a bug but keep it like this for
         // backwards compatibility and just take care to not return
@@ -678,11 +646,11 @@ wxFontEncoding wxLocale::GetSystemEncoding()
         {
             return enc;
         }
-        //else: return wxFONTENCODING_SYSTEM below
     }
-#endif // Win32/Unix
-
     return wxFONTENCODING_SYSTEM;
+#else
+    return wxFONTENCODING_SYSTEM;
+#endif
 }
 
 /* static */
@@ -729,7 +697,7 @@ const wxLanguageInfo* wxLocale::FindLanguageInfo(const wxString& locale)
 
 wxString wxLocale::GetSysName() const
 {
-    return wxSetlocale(LC_ALL, NULL);
+    return wxSetlocale(LC_ALL, nullptr);
 }
 
 // clean up
@@ -748,7 +716,7 @@ wxLocale::~wxLocale()
         if ( m_pOldLocale )
             wxTranslations::SetNonOwned(&m_pOldLocale->m_translations);
         else
-            wxTranslations::Set(NULL);
+            wxTranslations::Set(nullptr);
     }
 
     // restore old locale pointer
@@ -782,7 +750,7 @@ bool wxLocale::IsAvailable(int lang)
 
         // For this one, we need to check whether using it later is going to
         // actually work, i.e. if the CRT supports it.
-        const char* const origLocale = wxSetlocale(LC_ALL, NULL);
+        const char* const origLocale = wxSetlocale(LC_ALL, nullptr);
         if ( !origLocale )
         {
             // This is not supposed to happen, we should always be able to
@@ -830,22 +798,6 @@ bool wxLocale::AddCatalog(const wxString& domain, wxLanguage msgIdLanguage)
     return t->AddCatalog(domain, msgIdLanguage);
 }
 
-// add a catalog to our linked list
-bool wxLocale::AddCatalog(const wxString& szDomain,
-                        wxLanguage      msgIdLanguage,
-                        const wxString& msgIdCharset)
-{
-    wxTranslations *t = wxTranslations::Get();
-    if ( !t )
-        return false;
-#if wxUSE_UNICODE
-    wxUnusedVar(msgIdCharset);
-    return t->AddCatalog(szDomain, msgIdLanguage);
-#else
-    return t->AddCatalog(szDomain, msgIdLanguage, msgIdCharset);
-#endif
-}
-
 bool wxLocale::IsLoaded(const wxString& domain) const
 {
     wxTranslations *t = wxTranslations::Get();
@@ -1279,97 +1231,6 @@ wxString wxGetStdCLocaleInfo(wxLocaleInfo index, wxLocaleCategory WXUNUSED(cat))
 
 #if defined(__WINDOWS__)
 
-// These functions are also used by wxUILocaleImpl, so don't make them private.
-extern wxString
-wxGetInfoFromLCID(LCID lcid, wxLocaleInfo index, wxLocaleCategory cat);
-
-LCTYPE wxGetLCTYPEFormatFromLocalInfo(wxLocaleInfo index)
-{
-    switch ( index )
-    {
-        case wxLOCALE_SHORT_DATE_FMT:
-            return LOCALE_SSHORTDATE;
-
-        case wxLOCALE_LONG_DATE_FMT:
-            return LOCALE_SLONGDATE;
-
-        case wxLOCALE_TIME_FMT:
-            return LOCALE_STIMEFORMAT;
-
-        default:
-            wxFAIL_MSG( "no matching LCTYPE" );
-    }
-
-    return 0;
-}
-
-// This function is also used by wxUILocaleImpl, so don't make it private.
-wxString
-wxGetInfoFromLCID(LCID lcid, wxLocaleInfo index, wxLocaleCategory cat)
-{
-    wxString str;
-
-    wxChar buf[256];
-    buf[0] = wxT('\0');
-
-    switch ( index )
-    {
-        case wxLOCALE_THOUSANDS_SEP:
-            if ( ::GetLocaleInfo(lcid, LOCALE_STHOUSAND, buf, WXSIZEOF(buf)) )
-                str = buf;
-            break;
-
-        case wxLOCALE_DECIMAL_POINT:
-            if ( ::GetLocaleInfo(lcid,
-                                 cat == wxLOCALE_CAT_MONEY
-                                     ? LOCALE_SMONDECIMALSEP
-                                     : LOCALE_SDECIMAL,
-                                 buf,
-                                 WXSIZEOF(buf)) )
-            {
-                str = buf;
-            }
-            break;
-
-        case wxLOCALE_SHORT_DATE_FMT:
-        case wxLOCALE_LONG_DATE_FMT:
-        case wxLOCALE_TIME_FMT:
-            if ( ::GetLocaleInfo(lcid, wxGetLCTYPEFormatFromLocalInfo(index),
-                                 buf, WXSIZEOF(buf)) )
-            {
-                return wxTranslateFromUnicodeFormat(buf);
-            }
-            break;
-
-        case wxLOCALE_DATE_TIME_FMT:
-            // there doesn't seem to be any specific setting for this, so just
-            // combine date and time ones
-            //
-            // we use the short date because this is what "%c" uses by default
-            // ("%#c" uses long date but we have no way to specify the
-            // alternate representation here)
-            {
-                const wxString
-                    datefmt = wxGetInfoFromLCID(lcid, wxLOCALE_SHORT_DATE_FMT, cat);
-                if ( datefmt.empty() )
-                    break;
-
-                const wxString
-                    timefmt = wxGetInfoFromLCID(lcid, wxLOCALE_TIME_FMT, cat);
-                if ( timefmt.empty() )
-                    break;
-
-                str << datefmt << ' ' << timefmt;
-            }
-            break;
-
-        default:
-            wxFAIL_MSG( "unknown wxLocaleInfo" );
-    }
-
-    return str;
-}
-
 /* static */
 wxString wxLocale::GetInfo(wxLocaleInfo index, wxLocaleCategory cat)
 {
@@ -1388,7 +1249,7 @@ wxString wxLocale::GetOSInfo(wxLocaleInfo index, wxLocaleCategory cat)
 extern wxString
 wxGetInfoFromCFLocale(CFLocaleRef cfloc, wxLocaleInfo index, wxLocaleCategory WXUNUSED(cat))
 {
-    CFStringRef cfstr = 0;
+    CFStringRef cfstr = nullptr;
     switch ( index )
     {
         case wxLOCALE_THOUSANDS_SEP:
@@ -1426,7 +1287,7 @@ wxGetInfoFromCFLocale(CFLocaleRef cfloc, wxLocaleInfo index, wxLocaleCategory WX
                         return wxString();
                 }
                 wxCFRef<CFDateFormatterRef> dateFormatter( CFDateFormatterCreate
-                    (NULL, cfloc, dateStyle, timeStyle));
+                    (nullptr, cfloc, dateStyle, timeStyle));
                 wxCFStringRef cfs = wxCFRetain( CFDateFormatterGetFormat(dateFormatter ));
                 wxString format = wxTranslateFromUnicodeFormat(cfs.AsString());
                 // we always want full years
@@ -1608,7 +1469,7 @@ wxString wxLocale::GetOSInfo(wxLocaleInfo index, wxLocaleCategory cat)
 // ------------------------------
 
 // the current locale object
-static wxLocale *g_pLocale = NULL;
+static wxLocale *g_pLocale = nullptr;
 
 wxLocale *wxGetLocale()
 {
@@ -1634,12 +1495,12 @@ class wxLocaleModule: public wxModule
     public:
         wxLocaleModule() {}
 
-        bool OnInit() wxOVERRIDE
+        bool OnInit() override
         {
             return true;
         }
 
-        void OnExit() wxOVERRIDE
+        void OnExit() override
         {
             wxLocale::DestroyLanguagesDB();
         }
