@@ -2,7 +2,6 @@
 // Name:        src/generic/htmllbox.cpp
 // Purpose:     implementation of wxHtmlListBox
 // Author:      Vadim Zeitlin
-// Modified by:
 // Created:     31.05.03
 // Copyright:   (c) 2003 Vadim Zeitlin <vadim@wxwidgets.org>
 // Licence:     wxWindows licence
@@ -71,7 +70,7 @@ public:
         for ( size_t n = 0; n < SIZE; n++ )
         {
             m_items[n] = (size_t)-1;
-            m_cells[n] = NULL;
+            m_cells[n] = nullptr;
         }
 
         m_next = 0;
@@ -94,7 +93,7 @@ public:
         }
     }
 
-    // return the cached cell for this index or NULL if none
+    // return the cached cell for this index or nullptr if none
     wxHtmlCell *Get(size_t item) const
     {
         for ( size_t n = 0; n < SIZE; n++ )
@@ -103,11 +102,11 @@ public:
                 return m_cells[n];
         }
 
-        return NULL;
+        return nullptr;
     }
 
     // returns true if we already have this item cached
-    bool Has(size_t item) const { return Get(item) != NULL; }
+    bool Has(size_t item) const { return Get(item) != nullptr; }
 
     // ensure that the item is cached
     void Store(size_t item, wxHtmlCell *cell)
@@ -140,10 +139,10 @@ private:
     // the index of the LRU (oldest) cell
     size_t m_next;
 
-    // the parsed representation of the cached item or NULL
+    // the parsed representation of the cached item or nullptr
     wxHtmlCell *m_cells[SIZE];
 
-    // the index of the currently cached item (only valid if m_cells != NULL)
+    // the index of the currently cached item (only valid if m_cells != nullptr)
     size_t m_items[SIZE];
 };
 
@@ -160,7 +159,7 @@ public:
         : wxDefaultHtmlRenderingStyle(&hlbox), m_hlbox(hlbox)
     { }
 
-    virtual wxColour GetSelectedTextColour(const wxColour& colFg) wxOVERRIDE
+    virtual wxColour GetSelectedTextColour(const wxColour& colFg) override
     {
         // by default wxHtmlListBox doesn't implement GetSelectedTextColour()
         // and returns wxNullColour from it, so use the default HTML colour for
@@ -174,7 +173,7 @@ public:
         return col;
     }
 
-    virtual wxColour GetSelectedTextBgColour(const wxColour& colBg) wxOVERRIDE
+    virtual wxColour GetSelectedTextBgColour(const wxColour& colBg) override
     {
         wxColour col = m_hlbox.GetSelectedTextBgColour(colBg);
         if ( !col.IsOk() )
@@ -234,7 +233,7 @@ wxHtmlListBox::wxHtmlListBox(wxWindow *parent,
 
 void wxHtmlListBox::Init()
 {
-    m_htmlParser = NULL;
+    m_htmlParser = nullptr;
     m_htmlRendStyle = new wxHtmlListBoxStyle(*this);
     m_cache = new wxHtmlListBoxCache;
 }
@@ -303,17 +302,13 @@ wxHtmlCell* wxHtmlListBox::CreateCellForItem(size_t n) const
         self->m_htmlParser = new wxHtmlWinParser(self);
         m_htmlParser->SetDC(new wxClientDC(self));
         m_htmlParser->SetFS(&self->m_filesystem);
-#if !wxUSE_UNICODE
-        if (GetFont().IsOk())
-            m_htmlParser->SetInputEncoding(GetFont().GetEncoding());
-#endif
         // use system's default GUI font by default:
         m_htmlParser->SetStandardFonts();
     }
 
     wxHtmlContainerCell *cell = (wxHtmlContainerCell *)m_htmlParser->
             Parse(OnGetItemMarkup(n));
-    wxCHECK_MSG( cell, NULL, wxT("wxHtmlParser::Parse() returned NULL?") );
+    wxCHECK_MSG( cell, nullptr, wxT("wxHtmlParser::Parse() returned nullptr?") );
 
     // set the cell's ID to item's index so that CellCoordsToPhysical()
     // can quickly find the item:
@@ -502,10 +497,10 @@ wxCursor wxHtmlListBox::GetHTMLCursor(HTMLCursor type) const
 {
     // we don't want to show text selection cursor in listboxes
     if (type == HTMLCursor_Text)
-        return wxHtmlWindow::GetDefaultHTMLCursor(HTMLCursor_Default);
+        return wxHtmlWindow::GetDefaultHTMLCursor(HTMLCursor_Default, this);
 
     // in all other cases, use the same cursor as wxHtmlWindow:
-    return wxHtmlWindow::GetDefaultHTMLCursor(type);
+    return wxHtmlWindow::GetDefaultHTMLCursor(type, this);
 }
 
 // ----------------------------------------------------------------------------
@@ -698,7 +693,7 @@ int wxSimpleHtmlListBox::DoInsertItems(const wxArrayStringsAdapter& items,
     const unsigned int count = items.GetCount();
 
     m_items.Insert(wxEmptyString, pos, count);
-    m_HTMLclientData.Insert(NULL, pos, count);
+    m_HTMLclientData.Insert(nullptr, pos, count);
 
     for ( unsigned int i = 0; i < count; ++i, ++pos )
     {
