@@ -23,7 +23,7 @@
     #include "wx/control.h"
 #endif
 
-#ifdef __WXGTK20__
+#ifdef __WXGTK__
     #include "wx/gtk/private.h"
 #endif
 
@@ -48,7 +48,7 @@
 // GTK+ signal handler
 // ----------------------------------------------------------------------------
 
-#if defined( __WXGTK20__ )
+#if defined( __WXGTK__ )
 #if GTK_CHECK_VERSION(2,12,0)
 extern "C" {
 static
@@ -71,7 +71,7 @@ gboolean statusbar_query_tooltip(GtkWidget*   WXUNUSED(widget),
     if (str.empty())
         return FALSE;
 
-    gtk_tooltip_set_text(tooltip, wxGTK_CONV_SYS(str));
+    gtk_tooltip_set_text(tooltip, str.utf8_str());
     return TRUE;
 }
 }
@@ -85,7 +85,7 @@ gboolean statusbar_query_tooltip(GtkWidget*   WXUNUSED(widget),
 wxBEGIN_EVENT_TABLE(wxStatusBarGeneric, wxWindow)
     EVT_PAINT(wxStatusBarGeneric::OnPaint)
     EVT_SIZE(wxStatusBarGeneric::OnSize)
-#ifdef __WXGTK20__
+#ifdef __WXGTK__
     EVT_LEFT_DOWN(wxStatusBarGeneric::OnLeftDown)
     EVT_RIGHT_DOWN(wxStatusBarGeneric::OnRightDown)
 #endif
@@ -123,11 +123,11 @@ bool wxStatusBarGeneric::Create(wxWindow *parent,
 
     SetFieldsCount(1);
 
-#if defined( __WXGTK20__ )
+#if defined( __WXGTK__ )
 #if GTK_CHECK_VERSION(2,12,0)
     if (HasFlag(wxSTB_SHOW_TIPS) && wx_is_at_least_gtk2(12))
     {
-        g_object_set(m_widget, "has-tooltip", TRUE, NULL);
+        g_object_set(m_widget, "has-tooltip", TRUE, nullptr);
         g_signal_connect(m_widget, "query-tooltip",
                          G_CALLBACK(statusbar_query_tooltip), this);
     }
@@ -143,7 +143,7 @@ wxSize wxStatusBarGeneric::DoGetBestSize() const
 
     // best width is the width of the parent
     if (GetParent())
-        GetParent()->GetClientSize(&width, NULL);
+        GetParent()->GetClientSize(&width, nullptr);
     else
         width = 80;     // a dummy value
 
@@ -192,16 +192,16 @@ void wxStatusBarGeneric::DoUpdateFieldWidths()
 bool wxStatusBarGeneric::ShowsSizeGrip() const
 {
     // Currently drawing size grip is implemented only in wxGTK.
-#ifdef __WXGTK20__
+#ifdef __WXGTK__
     if ( !HasFlag(wxSTB_SIZEGRIP) )
         return false;
 
     wxTopLevelWindow * const
         tlw = wxDynamicCast(wxGetTopLevelParent(GetParent()), wxTopLevelWindow);
     return tlw && !tlw->IsMaximized() && tlw->HasFlag(wxRESIZE_BORDER);
-#else // !__WXGTK20__
+#else // !__WXGTK__
     return false;
-#endif // __WXGTK20__/!__WXGTK20__
+#endif // __WXGTK__/!__WXGTK__
 }
 
 void wxStatusBarGeneric::DrawFieldText(wxDC& dc, const wxRect& rect, int i, int textHeight)
@@ -405,7 +405,7 @@ void wxStatusBarGeneric::OnPaint(wxPaintEvent& WXUNUSED(event) )
 {
     wxPaintDC dc(this);
 
-#ifdef __WXGTK20__
+#ifdef __WXGTK__
     // Draw grip first
     if ( ShowsSizeGrip() )
     {
@@ -433,17 +433,14 @@ void wxStatusBarGeneric::OnPaint(wxPaintEvent& WXUNUSED(event) )
         gtk_paint_resize_grip(gtk_widget_get_style(m_widget),
                             GTKGetDrawingWindow(),
                             gtk_widget_get_state(m_widget),
-                            NULL,
+                            nullptr,
                             m_widget,
                             "statusbar",
                             edge,
                             rc.x, rc.y, rc.width, rc.height );
 #endif
     }
-#endif // __WXGTK20__
-
-    if (GetFont().IsOk())
-        dc.SetFont(GetFont());
+#endif // __WXGTK__
 
     // compute char height only once for all panes:
     int textHeight = dc.GetCharHeight();
@@ -461,7 +458,7 @@ void wxStatusBarGeneric::OnSysColourChanged(wxSysColourChangedEvent& event)
     wxWindow::OnSysColourChanged(event);
 }
 
-#ifdef __WXGTK20__
+#ifdef __WXGTK__
 void wxStatusBarGeneric::OnLeftDown(wxMouseEvent& event)
 {
     int width, height;
@@ -475,7 +472,7 @@ void wxStatusBarGeneric::OnLeftDown(wxMouseEvent& event)
         rect.width && rect.height)
     wxGCC_WARNING_RESTORE()
     {
-        ancestor = NULL;
+        ancestor = nullptr;
     }
 #endif
 
@@ -525,7 +522,7 @@ void wxStatusBarGeneric::OnRightDown(wxMouseEvent& event)
         rect.width && rect.height)
     wxGCC_WARNING_RESTORE()
     {
-        ancestor = NULL;
+        ancestor = nullptr;
     }
 #endif
 
@@ -548,7 +545,7 @@ void wxStatusBarGeneric::OnRightDown(wxMouseEvent& event)
         event.Skip( true );
     }
 }
-#endif // __WXGTK20__
+#endif // __WXGTK__
 
 void wxStatusBarGeneric::OnSize(wxSizeEvent& event)
 {
