@@ -2,7 +2,6 @@
 // Name:        src/msw/ole/dataobj.cpp
 // Purpose:     implementation of wx[I]DataObject class
 // Author:      Vadim Zeitlin
-// Modified by:
 // Created:     10.05.98
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows licence
@@ -93,7 +92,7 @@ wxDataFormat NonStandardFormatsFixup(wxDataFormat format)
 // helper function for wxCopyStgMedium()
 HGLOBAL wxGlobalClone(HGLOBAL hglobIn)
 {
-    HGLOBAL hglobOut = NULL;
+    HGLOBAL hglobOut = nullptr;
 
     GlobalPtrLock ptrIn(hglobIn);
     if (ptrIn)
@@ -119,7 +118,7 @@ HRESULT wxCopyStgMedium(const STGMEDIUM *pmediumIn, STGMEDIUM *pmediumOut)
     HRESULT hres = S_OK;
     STGMEDIUM stgmOut = *pmediumIn;
 
-    if (pmediumIn->pUnkForRelease == NULL &&
+    if (pmediumIn->pUnkForRelease == nullptr &&
         !(pmediumIn->tymed & (TYMED_ISTREAM | TYMED_ISTORAGE)))
     {
         // Object needs to be cloned.
@@ -174,10 +173,10 @@ public:
     virtual ~wxIEnumFORMATETC() { delete [] m_formats; }
 
     // IEnumFORMATETC
-    STDMETHODIMP Next(ULONG celt, FORMATETC *rgelt, ULONG *pceltFetched) wxOVERRIDE;
-    STDMETHODIMP Skip(ULONG celt) wxOVERRIDE;
-    STDMETHODIMP Reset() wxOVERRIDE;
-    STDMETHODIMP Clone(IEnumFORMATETC **ppenum) wxOVERRIDE;
+    STDMETHODIMP Next(ULONG celt, FORMATETC *rgelt, ULONG *pceltFetched) override;
+    STDMETHODIMP Skip(ULONG celt) override;
+    STDMETHODIMP Reset() override;
+    STDMETHODIMP Clone(IEnumFORMATETC **ppenum) override;
 
     DECLARE_IUNKNOWN_METHODS;
 
@@ -205,15 +204,15 @@ public:
     void SetDeleteFlag() { m_mustDelete = true; }
 
     // IDataObject
-    STDMETHODIMP GetData(FORMATETC *pformatetcIn, STGMEDIUM *pmedium) wxOVERRIDE;
-    STDMETHODIMP GetDataHere(FORMATETC *pformatetc, STGMEDIUM *pmedium) wxOVERRIDE;
-    STDMETHODIMP QueryGetData(FORMATETC *pformatetc) wxOVERRIDE;
-    STDMETHODIMP GetCanonicalFormatEtc(FORMATETC *In, FORMATETC *pOut) wxOVERRIDE;
-    STDMETHODIMP SetData(FORMATETC *pfetc, STGMEDIUM *pmedium, BOOL fRelease) wxOVERRIDE;
-    STDMETHODIMP EnumFormatEtc(DWORD dwDirection, IEnumFORMATETC **ppenumFEtc) wxOVERRIDE;
-    STDMETHODIMP DAdvise(FORMATETC *pfetc, DWORD ad, IAdviseSink *p, DWORD *pdw) wxOVERRIDE;
-    STDMETHODIMP DUnadvise(DWORD dwConnection) wxOVERRIDE;
-    STDMETHODIMP EnumDAdvise(IEnumSTATDATA **ppenumAdvise) wxOVERRIDE;
+    STDMETHODIMP GetData(FORMATETC *pformatetcIn, STGMEDIUM *pmedium) override;
+    STDMETHODIMP GetDataHere(FORMATETC *pformatetc, STGMEDIUM *pmedium) override;
+    STDMETHODIMP QueryGetData(FORMATETC *pformatetc) override;
+    STDMETHODIMP GetCanonicalFormatEtc(FORMATETC *In, FORMATETC *pOut) override;
+    STDMETHODIMP SetData(FORMATETC *pfetc, STGMEDIUM *pmedium, BOOL fRelease) override;
+    STDMETHODIMP EnumFormatEtc(DWORD dwDirection, IEnumFORMATETC **ppenumFEtc) override;
+    STDMETHODIMP DAdvise(FORMATETC *pfetc, DWORD ad, IAdviseSink *p, DWORD *pdw) override;
+    STDMETHODIMP DUnadvise(DWORD dwConnection) override;
+    STDMETHODIMP EnumDAdvise(IEnumSTATDATA **ppenumAdvise) override;
 
     DECLARE_IUNKNOWN_METHODS;
 
@@ -299,7 +298,7 @@ wxIDataObject::SaveSystemData(FORMATETC *pformatetc,
                                  STGMEDIUM *pmedium,
                                  BOOL fRelease)
 {
-    if ( pformatetc == NULL || pmedium == NULL )
+    if ( pformatetc == nullptr || pmedium == nullptr )
         return E_INVALIDARG;
 
     // remove entry if already available
@@ -444,7 +443,7 @@ STDMETHODIMP wxIEnumFORMATETC::Next(ULONG      celt,
     while (m_nCurrent < m_nCount && numFetched < celt) {
         FORMATETC format;
         format.cfFormat = m_formats[m_nCurrent++];
-        format.ptd      = NULL;
+        format.ptd      = nullptr;
         format.dwAspect = DVASPECT_CONTENT;
         format.lindex   = -1;
         format.tymed    = TYMED_HGLOBAL;
@@ -487,7 +486,7 @@ STDMETHODIMP wxIEnumFORMATETC::Clone(IEnumFORMATETC **ppenum)
     wxLogTrace(wxTRACE_OleCalls, wxT("wxIEnumFORMATETC::Clone"));
 
     // unfortunately, we can't reuse the code in ctor - types are different
-    wxIEnumFORMATETC *pNew = new wxIEnumFORMATETC(NULL, 0);
+    wxIEnumFORMATETC *pNew = new wxIEnumFORMATETC(nullptr, 0);
     pNew->m_nCount = m_nCount;
     pNew->m_formats = new CLIPFORMAT[m_nCount];
     for ( ULONG n = 0; n < m_nCount; n++ ) {
@@ -587,7 +586,7 @@ STDMETHODIMP wxIDataObject::GetData(FORMATETC *pformatetcIn, STGMEDIUM *pmedium)
             size += m_pDataObject->GetBufferOffset( format );
 
             HGLOBAL hGlobal = GlobalAlloc(GMEM_MOVEABLE | GMEM_SHARE, size);
-            if ( hGlobal == NULL ) {
+            if ( hGlobal == nullptr ) {
                 wxLogLastError(wxT("GlobalAlloc"));
                 return E_OUTOFMEMORY;
             }
@@ -597,7 +596,7 @@ STDMETHODIMP wxIDataObject::GetData(FORMATETC *pformatetcIn, STGMEDIUM *pmedium)
             pmedium->hGlobal = hGlobal;
     }
 
-    pmedium->pUnkForRelease = NULL;
+    pmedium->pUnkForRelease = nullptr;
 
     // do copy the data
     hr = GetDataHere(pformatetcIn, pmedium);
@@ -798,7 +797,7 @@ STDMETHODIMP wxIDataObject::SetData(FORMATETC *pformatetc,
 STDMETHODIMP wxIDataObject::QueryGetData(FORMATETC *pformatetc)
 {
     // do we accept data in this format?
-    if ( pformatetc == NULL ) {
+    if ( pformatetc == nullptr ) {
         wxLogTrace(wxTRACE_OleCalls,
                    wxT("wxIDataObject::QueryGetData: invalid ptr."));
 
@@ -869,8 +868,8 @@ STDMETHODIMP wxIDataObject::GetCanonicalFormatEtc(FORMATETC *WXUNUSED(pFormatetc
     wxLogTrace(wxTRACE_OleCalls, wxT("wxIDataObject::GetCanonicalFormatEtc"));
 
     // TODO we might want something better than this trivial implementation here
-    if ( pFormatetcOut != NULL )
-        pFormatetcOut->ptd = NULL;
+    if ( pFormatetcOut != nullptr )
+        pFormatetcOut->ptd = nullptr;
 
     return DATA_S_SAMEFORMATETC;
 }
@@ -954,7 +953,7 @@ void wxDataObject::SetAutoDelete()
     m_pIDataObject->Release();
 
     // so that the dtor doesn't crash
-    m_pIDataObject = NULL;
+    m_pIDataObject = nullptr;
 }
 
 size_t wxDataObject::GetBufferOffset(const wxDataFormat& format )
@@ -971,7 +970,7 @@ const void *wxDataObject::GetSizeFromBuffer(const void *buffer,
     if ( !realsz )
     {
         wxLogLastError(wxT("GlobalSize"));
-        return NULL;
+        return nullptr;
     }
 
     *size = realsz;
@@ -1078,7 +1077,7 @@ size_t wxBitmapDataObject::GetDataSize() const
     // because the size of the bitmap without the alpha channel is different.
     RemoveAlphaIfNecessary(bmp);
 
-    return wxDIB::ConvertFromBitmap(NULL, GetHbitmapOf(bmp));
+    return wxDIB::ConvertFromBitmap(nullptr, GetHbitmapOf(bmp));
 #else
     return 0;
 #endif
@@ -1185,9 +1184,9 @@ size_t wxBitmapDataObject::GetDataSize(const wxDataFormat& format) const
         // first get the info
         BITMAPINFO bi;
         if ( !GetDIBits(hdc, (HBITMAP)m_bitmap.GetHBITMAP(), 0, 0,
-                        NULL, &bi, DIB_RGB_COLORS) )
+                        nullptr, &bi, DIB_RGB_COLORS) )
         {
-            wxLogLastError(wxT("GetDIBits(NULL)"));
+            wxLogLastError(wxT("GetDIBits(nullptr)"));
 
             return 0;
         }
@@ -1218,9 +1217,9 @@ bool wxBitmapDataObject::GetDataHere(const wxDataFormat& format,
 
         // first get the info
         BITMAPINFO *pbi = (BITMAPINFO *)pBuf;
-        if ( !GetDIBits(hdc, hbmp, 0, 0, NULL, pbi, DIB_RGB_COLORS) )
+        if ( !GetDIBits(hdc, hbmp, 0, 0, nullptr, pbi, DIB_RGB_COLORS) )
         {
-            wxLogLastError(wxT("GetDIBits(NULL)"));
+            wxLogLastError(wxT("GetDIBits(nullptr)"));
 
             return 0;
         }
@@ -1310,7 +1309,7 @@ bool wxFileDataObject::SetData(size_t WXUNUSED(size),
     HDROP hdrop = static_cast<HDROP>(const_cast<void*>(pData));   // NB: it works, but I'm not sure about it
 
     // get number of files (magic value -1)
-    UINT nFiles = ::DragQueryFile(hdrop, (unsigned)-1, NULL, 0u);
+    UINT nFiles = ::DragQueryFile(hdrop, (unsigned)-1, nullptr, 0u);
 
     wxCHECK_MSG ( nFiles != (UINT)-1, FALSE, wxT("wrong HDROP handle") );
 
@@ -1319,7 +1318,7 @@ bool wxFileDataObject::SetData(size_t WXUNUSED(size),
     UINT len, n;
     for ( n = 0; n < nFiles; n++ ) {
         // +1 for terminating NUL
-        len = ::DragQueryFile(hdrop, n, NULL, 0) + 1;
+        len = ::DragQueryFile(hdrop, n, nullptr, 0) + 1;
 
         UINT len2 = ::DragQueryFile(hdrop, n, wxStringBuffer(str, len), len);
         m_filenames.Add(str);
@@ -1372,7 +1371,7 @@ bool wxFileDataObject::GetDataHere(void *pData) const
     // pData points to an externally allocated memory block
     // created using the size returned by GetDataSize()
 
-    // if pData is NULL, or there are no files, return
+    // if pData is null, or there are no files, return
     if ( !pData || m_filenames.empty() )
         return false;
 
@@ -1382,7 +1381,7 @@ bool wxFileDataObject::GetDataHere(void *pData) const
     // initialize DROPFILES struct
     pDrop->pFiles = sizeof(DROPFILES);
     pDrop->fNC = FALSE;                 // not non-client coords
-    pDrop->fWide = wxUSE_UNICODE;
+    pDrop->fWide = TRUE;
 
     const size_t sizeOfChar = pDrop->fWide ? sizeof(wchar_t) : 1;
 
@@ -1413,7 +1412,7 @@ bool wxFileDataObject::GetDataHere(void *pData) const
 // ----------------------------------------------------------------------------
 
 // Work around bug in Wine headers
-#if defined(__WINE__) && defined(CFSTR_SHELLURL) && wxUSE_UNICODE
+#if defined(__WINE__) && defined(CFSTR_SHELLURL)
 #undef CFSTR_SHELLURL
 #define CFSTR_SHELLURL wxT("CFSTR_SHELLURL")
 #endif
@@ -1423,13 +1422,13 @@ class CFSTR_SHELLURLDataObject : public wxCustomDataObject
 public:
     CFSTR_SHELLURLDataObject() : wxCustomDataObject(CFSTR_SHELLURL) {}
 
-    virtual size_t GetBufferOffset( const wxDataFormat& WXUNUSED(format) ) wxOVERRIDE
+    virtual size_t GetBufferOffset( const wxDataFormat& WXUNUSED(format) ) override
     {
         return 0;
     }
 
     virtual const void* GetSizeFromBuffer( const void* buffer, size_t* size,
-                                           const wxDataFormat& WXUNUSED(format) ) wxOVERRIDE
+                                           const wxDataFormat& WXUNUSED(format) ) override
     {
         // CFSTR_SHELLURL is _always_ ANSI text
         *size = strlen( (const char*)buffer );
@@ -1438,7 +1437,7 @@ public:
     }
 
     virtual void* SetSizeInBuffer( void* buffer, size_t WXUNUSED(size),
-                                   const wxDataFormat& WXUNUSED(format) ) wxOVERRIDE
+                                   const wxDataFormat& WXUNUSED(format) ) override
     {
         return buffer;
     }
@@ -1457,7 +1456,7 @@ wxURLDataObject::wxURLDataObject(const wxString& url)
     Add(new CFSTR_SHELLURLDataObject());
 
     // we don't have any data yet
-    m_dataObjectLast = NULL;
+    m_dataObjectLast = nullptr;
 
     if ( !url.empty() )
         SetURL(url);
@@ -1488,15 +1487,10 @@ wxString wxURLDataObject::GetURL() const
 
         // CFSTR_SHELLURL is always ANSI so we need to convert it from it in
         // Unicode build
-#if wxUSE_UNICODE
         wxCharBuffer buf(len);
 
         if ( m_dataObjectLast->GetDataHere(buf.data()) )
             url = buf;
-#else // !wxUSE_UNICODE
-        // in ANSI build no conversion is necessary
-        m_dataObjectLast->GetDataHere(wxStringBuffer(url, len));
-#endif // wxUSE_UNICODE/!wxUSE_UNICODE
     }
     else // must be wxTextDataObject
     {
@@ -1513,21 +1507,13 @@ void wxURLDataObject::SetURL(const wxString& url)
     {
         const size_t len = strlen(urlMB);
 
-#if !wxUSE_UNICODE
-        // wxTextDataObject takes the number of characters in the string, not
-        // the size of the buffer (which would be len+1)
-        SetData(wxDF_TEXT, len, urlMB);
-#endif // !wxUSE_UNICODE
-
         // however CFSTR_SHELLURLDataObject doesn't append NUL automatically
         // but we probably still want to have it on the clipboard (just to be
         // safe), so do append it
         SetData(wxDataFormat(CFSTR_SHELLURL), len + 1, urlMB);
     }
 
-#if wxUSE_UNICODE
     SetData(wxDF_UNICODETEXT, (url.length() + 1)*sizeof(wxChar), url.wc_str());
-#endif
 }
 
 #if wxUSE_OLE
@@ -1576,14 +1562,14 @@ void wxDataObject::SetAutoDelete()
 
 const wxChar *wxDataObject::GetFormatName(wxDataFormat WXUNUSED(format))
 {
-    return NULL;
+    return nullptr;
 }
 
 const void* wxDataObject::GetSizeFromBuffer(const void* WXUNUSED(buffer),
     size_t* size, const wxDataFormat& WXUNUSED(format))
 {
     *size = 0;
-    return NULL;
+    return nullptr;
 }
 
 void* wxDataObject::SetSizeInBuffer(void* buffer, size_t WXUNUSED(size),
