@@ -2,7 +2,6 @@
 // Name:        src/msw/statbox.cpp
 // Purpose:     wxStaticBox
 // Author:      Julian Smart
-// Modified by:
 // Created:     04/01/98
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
@@ -42,6 +41,7 @@
 #include "wx/msw/private.h"
 #include "wx/msw/missing.h"
 #include "wx/msw/dc.h"
+#include "wx/msw/private/darkmode.h"
 #include "wx/msw/private/winstyle.h"
 
 namespace
@@ -89,18 +89,55 @@ bool wxStaticBox::Create(wxWindow *parent,
     if ( !MSWCreateControl(wxT("BUTTON"), label, pos, size) )
         return false;
 
-    if (!wxSystemOptions::IsFalse(wxT("msw.staticbox.optimized-paint")))
+    if ( ShouldUseCustomPaint() )
+        UseCustomPaint();
+
+    return true;
+}
+
+bool wxStaticBox::MSWGetDarkModeSupport(MSWDarkModeSupport& support) const
+{
+    // Static boxes don't seem to have any dark mode support, so just set the
+    // foreground colour contrasting with the dark background for them.
+    support.setForeground = true;
+
+    return true;
+}
+
+bool wxStaticBox::ShouldUseCustomPaint() const
+{
+    // When not using double buffering, we paint the box ourselves by default
+    // because using the standard control default WM_PAINT handler results in
+    // awful flicker. However this can be disabled by setting a system option
+    // which can be useful if the application paints on the box itself (which
+    // should be avoided, but some existing code does it).
+    return !IsDoubleBuffered() &&
+            !wxSystemOptions::IsFalse(wxT("msw.staticbox.optimized-paint"));
+}
+
+void wxStaticBox::UseCustomPaint()
+{
+    // If background style is already set to this value, we must have been
+    // already called -- and as we currently never unbind the handler, this
+    // means we don't need to do anything.
+    if ( GetBackgroundStyle() != wxBG_STYLE_PAINT )
     {
+        wxMSWWinExStyleUpdater(GetHwnd()).TurnOff(WS_EX_TRANSPARENT);
+
         Bind(wxEVT_PAINT, &wxStaticBox::OnPaint, this);
 
         // Our OnPaint() completely erases our background, so don't do it in
         // WM_ERASEBKGND too to avoid flicker.
         SetBackgroundStyle(wxBG_STYLE_PAINT);
     }
+}
 
-    Bind(wxEVT_DPI_CHANGED, &wxStaticBox::OnDPIChanged, this);
-
-    return true;
+void wxStaticBox::MSWOnDisabledComposited()
+{
+    // We need to enable custom painting if we're not using compositing any
+    // longer, as otherwise the window is not drawn correctly due to it using
+    // WS_EX_TRANSPARENT and thus not redrawing its background.
+    UseCustomPaint();
 }
 
 bool wxStaticBox::Create(wxWindow* parent,
@@ -127,7 +164,10 @@ bool wxStaticBox::Create(wxWindow* parent,
 void wxStaticBox::PositionLabelWindow()
 {
     m_labelWin->SetSize(m_labelWin->GetBestSize());
-    m_labelWin->Move(FromDIP(LABEL_HORZ_OFFSET), 0);
+
+    // Note that we intentionally don't use FromDIP() with the label offset
+    // here, see comment in PaintForeground() where it is also used.
+    m_labelWin->Move(LABEL_HORZ_OFFSET, 0);
 }
 
 wxWindowList wxStaticBox::GetCompositeWindowParts() const
@@ -154,7 +194,7 @@ WXDWORD wxStaticBox::MSWGetStyle(long style, WXDWORD *exstyle) const
         // navigation ourselves, but this could change in the future).
         *exstyle |= WS_EX_CONTROLPARENT;
 
-        if (wxSystemOptions::IsFalse(wxT("msw.staticbox.optimized-paint")))
+        if ( !ShouldUseCustomPaint() )
             *exstyle |= WS_EX_TRANSPARENT;
     }
 
@@ -178,7 +218,7 @@ wxSize wxStaticBox::DoGetBestSize() const
     int hBox = EDIT_HEIGHT_FROM_CHAR_HEIGHT(cy);
 
     // If there is a sizer then the base best size is the sizer's minimum
-    if (GetSizer() != NULL)
+    if (GetSizer() != nullptr)
     {
         wxSize cm(GetSizer()->CalcMin());
         best = ClientToWindowSize(cm);
@@ -215,7 +255,9 @@ void wxStaticBox::GetBordersForSizer(int *borderTop, int *borderOther) const
         *borderTop = 2*FromDIP(CHILDREN_OFFSET);
     }
 
-    *borderTop += FromDIP(LABEL_VERT_BORDER);
+    // Intentionally don't scale this one by DPI, as it's not scaled when it is
+    // actually used in the drawing code, see comments there.
+    *borderTop += LABEL_VERT_BORDER;
 
     *borderOther = FromDIP(CHILDREN_OFFSET);
 }
@@ -230,9 +272,24 @@ bool wxStaticBox::SetBackgroundColour(const wxColour& colour)
     return wxStaticBoxBase::SetBackgroundColour(colour);
 }
 
+bool wxStaticBox::SetForegroundColour(const wxColour& colour)
+{
+    if ( !base_type::SetForegroundColour(colour) )
+        return false;
+
+    if ( colour.IsOk() && !m_labelWin )
+    {
+        // We need to be using our custom paint handler to support non-default
+        // colours.
+        UseCustomPaint();
+    }
+
+    return true;
+}
+
 bool wxStaticBox::SetFont(const wxFont& font)
 {
-    if ( !wxCompositeWindowSettersOnly<wxStaticBoxBase>::SetFont(font) )
+    if ( !base_type::SetFont(font) )
         return false;
 
     // We need to reposition the label as its size may depend on the font.
@@ -287,28 +344,10 @@ WXLRESULT wxStaticBox::MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lPar
         return 0;
     }
 
-    if ( nMsg == WM_UPDATEUISTATE )
-    {
-        // DefWindowProc() redraws just the static box text when it gets this
-        // message and it does it using the standard (blue in standard theme)
-        // colour and not our own label colour that we use in PaintForeground()
-        // resulting in the label mysteriously changing the colour when e.g.
-        // "Alt" is pressed anywhere in the window, see #12497.
-        //
-        // To avoid this we simply refresh the window forcing our own code
-        // redrawing the label in the correct colour to be called. This is
-        // inefficient but there doesn't seem to be anything else we can do.
-        //
-        // Notice that the problem is XP-specific and doesn't arise under later
-        // systems.
-        if ( m_hasFgCol && wxGetWinVersion() == wxWinVersion_XP )
-            Refresh();
-    }
-
     return wxControl::MSWWindowProc(nMsg, wParam, lParam);
 }
 
-void wxStaticBox::OnDPIChanged(wxDPIChangedEvent& WXUNUSED(event))
+void wxStaticBox::MSWBeforeDPIChangedEvent(const wxDPIChangedEvent& WXUNUSED(event))
 {
     if ( m_labelWin )
         PositionLabelWindow();
@@ -355,7 +394,7 @@ void wxStaticBox::MSWGetRegionWithoutSelf(WXHRGN hRgn, int w, int h)
         // the background of the gap between the label window and the box
         // frame.
         const wxRect labelRect = m_labelWin->GetRect();
-        const int gap = FromDIP(LABEL_HORZ_BORDER);
+        const int gap = LABEL_HORZ_BORDER;
 
         SubtractRectFromRgn(hrgn, 0, 0, labelRect.GetLeft() - gap, borderTop);
         SubtractRectFromRgn(hrgn, labelRect.GetRight() + gap, 0, w, borderTop);
@@ -416,7 +455,7 @@ WXHRGN wxStaticBox::MSWGetRegionWithoutChildren()
 
         wxMSWWinStyleUpdater updateStyle(child);
         wxString str(wxGetWindowClass(child));
-        str.UpperCase();
+        str.MakeUpper();
         if ( str == wxT("BUTTON") && updateStyle.IsOn(BS_GROUPBOX) )
         {
             if ( child == GetHwnd() )
@@ -447,7 +486,7 @@ WXHRGN wxStaticBox::MSWGetRegionWithoutChildren()
                 // MSDN: "If you have changed certain window data using
                 // SetWindowLong, you must call SetWindowPos to have the
                 // changes take effect."
-                ::SetWindowPos(child, NULL, 0, 0, 0, 0,
+                ::SetWindowPos(child, nullptr, 0, 0, 0, 0,
                                SWP_NOMOVE | SWP_NOSIZE | SWP_NOZORDER |
                                SWP_FRAMECHANGED);
             }
@@ -502,14 +541,59 @@ void wxStaticBox::PaintBackground(wxDC& dc, const RECT& rc)
 void wxStaticBox::PaintForeground(wxDC& dc, const RECT&)
 {
     wxMSWDCImpl *impl = (wxMSWDCImpl*) dc.GetImpl();
-    MSWDefWindowProc(WM_PAINT, (WPARAM)GetHdcOf(*impl), 0);
+
+    // Optionally use this pen to draw a border which has less contrast in dark
+    // mode than the default white box which is "too shiny"
+    wxPen penBorder;
+    if ( wxMSWDarkMode::IsActive() )
+    {
+        penBorder = wxMSWDarkMode::GetBorderPen();
+    }
+
+    if ( penBorder.IsOk() )
+    {
+        const wxRect clientRect = GetClientRect();
+        wxRect rect = clientRect;
+        wxDCBrushChanger brushChanger(dc, *wxTRANSPARENT_BRUSH);
+        wxDCPenChanger penChanger(dc, penBorder);
+
+        // Note that we want to to do this even if our label is empty because
+        // this ensures that the border appears at the same position for the
+        // boxes with and without labels.
+        if ( !m_labelWin )
+        {
+            // if the control has a font, use it
+            wxDCFontChanger fontChanger(dc);
+            if ( GetFont().IsOk() )
+            {
+                dc.SetFont(GetFont());
+            }
+
+            // Make sure that the label is vertically aligned with the border
+            //
+            // Use "Tp" as our sampling text to get the
+            // maximum height from the current font
+            const wxCoord height = dc.GetTextExtent(L"Tp").y;
+
+            // adjust the border height & Y coordinate
+            const int offsetFromTop = height / 2;
+            rect.SetTop(offsetFromTop);
+            rect.SetHeight(rect.GetHeight() - offsetFromTop);
+        }
+
+        dc.DrawRectangle(rect);
+    }
+    else
+    {
+        MSWDefWindowProc(WM_PAINT, (WPARAM)GetHdcOf(*impl), 0);
+    }
 
 #if wxUSE_UXTHEME
     // when using XP themes, neither setting the text colour nor transparent
     // background mode changes anything: the static box def window proc
     // still draws the label in its own colours, so we need to redraw the text
     // ourselves if we have a non default fg colour
-    if ( m_hasFgCol && wxUxThemeIsActive() && !m_labelWin )
+    if ( m_hasFgCol && wxUxThemeIsActive() && !m_labelWin && !GetLabel().empty() )
     {
         // draw over the text in default colour in our colour
         HDC hdc = GetHdcOf(*impl);
@@ -530,7 +614,7 @@ void wxStaticBox::PaintForeground(wxDC& dc, const RECT&)
             wxUxThemeHandle hTheme(this, L"BUTTON");
             if ( hTheme )
             {
-                wxUxThemeFont themeFont;
+                LOGFONTW themeFont;
                 if ( ::GetThemeFont
                                              (
                                                 hTheme,
@@ -538,10 +622,10 @@ void wxStaticBox::PaintForeground(wxDC& dc, const RECT&)
                                                 BP_GROUPBOX,
                                                 GBS_NORMAL,
                                                 TMT_FONT,
-                                                themeFont.GetPtr()
+                                                &themeFont
                                              ) == S_OK )
                 {
-                    font.Init(themeFont.GetLOGFONT());
+                    font.Init(themeFont);
                     if ( font )
                         selFont.Init(hdc, font);
                 }
@@ -614,7 +698,11 @@ void wxStaticBox::OnPaint(wxPaintEvent& WXUNUSED(event))
 
     // draw the entire box in a memory DC
     wxMemoryDC memdc(&dc);
-    wxBitmap bitmap(rc.right, rc.bottom);
+
+    const double scale = dc.GetContentScaleFactor();
+    wxBitmap bitmap;
+    // Physical and logical sizes are the same in wxMSW.
+    bitmap.CreateWithLogicalSize(rc.right, rc.bottom, scale);
     memdc.SelectObject(bitmap);
 
     PaintBackground(memdc, rc);
