@@ -269,7 +269,7 @@ bool wxApp::Initialize(int& argc, wxChar **argv)
      -NSShowAllViews YES.  Cocoa picks these up from the real argv so
      our removal of them from the wx copy of it does not affect Cocoa's
      ability to see them.
-     
+
      We basically just assume that any "-NS" option and its following
      argument needs to be removed from argv.  We hope that user code does
      not expect to see -NS options and indeed it's probably a safe bet
@@ -297,7 +297,12 @@ bool wxApp::Initialize(int& argc, wxChar **argv)
         return false;
 
 #if wxUSE_INTL
-    wxFont::SetDefaultEncoding(wxLocale::GetSystemEncoding());
+    // Check if we recognize the system encoding. Note that we must not call
+    // SetDefaultEncoding() if we don't, as indicated by wxFONTENCODING_DEFAULT
+    // being returned, as SetDefaultEncoding() would assert in this case.
+    const wxFontEncoding defaultEncoding = wxLocale::GetSystemEncoding();
+    if ( defaultEncoding != wxFONTENCODING_DEFAULT )
+        wxFont::SetDefaultEncoding(defaultEncoding);
 #endif
 
     // these might be the startup dirs, set them to the 'usual' dir containing the app bundle
@@ -472,7 +477,7 @@ void wxApp::MacHandleUnhandledEvent( WXEVENTREF WXUNUSED(evr) )
 CGKeyCode wxCharCodeWXToOSX(wxKeyCode code)
 {
     CGKeyCode keycode;
-    
+
     switch (code)
     {
         // Clang warns about switch values not of the same type as (enumerated)
@@ -510,7 +515,7 @@ CGKeyCode wxCharCodeWXToOSX(wxKeyCode code)
         case 'x': case 'X':   keycode = kVK_ANSI_X; break;
         case 'y': case 'Y':   keycode = kVK_ANSI_Y; break;
         case 'z': case 'Z':   keycode = kVK_ANSI_Z; break;
-            
+
         case '0':             keycode = kVK_ANSI_0; break;
         case '1':             keycode = kVK_ANSI_1; break;
         case '2':             keycode = kVK_ANSI_2; break;
@@ -525,19 +530,19 @@ CGKeyCode wxCharCodeWXToOSX(wxKeyCode code)
 #ifdef __clang__
     #pragma clang diagnostic pop
 #endif // __clang__
-            
+
         case WXK_BACK:        keycode = kVK_Delete; break;
         case WXK_TAB:         keycode = kVK_Tab; break;
         case WXK_RETURN:      keycode = kVK_Return; break;
         case WXK_ESCAPE:      keycode = kVK_Escape; break;
         case WXK_SPACE:       keycode = kVK_Space; break;
         case WXK_DELETE:      keycode = kVK_ForwardDelete; break;
-            
+
         case WXK_SHIFT:       keycode = kVK_Shift; break;
         case WXK_ALT:         keycode = kVK_Option; break;
         case WXK_RAW_CONTROL: keycode = kVK_Control; break;
         case WXK_CONTROL:     keycode = kVK_Command; break;
-            
+
         case WXK_CAPITAL:     keycode = kVK_CapsLock; break;
         case WXK_END:         keycode = kVK_End; break;
         case WXK_HOME:        keycode = kVK_Home; break;
@@ -545,10 +550,10 @@ CGKeyCode wxCharCodeWXToOSX(wxKeyCode code)
         case WXK_UP:          keycode = kVK_UpArrow; break;
         case WXK_RIGHT:       keycode = kVK_RightArrow; break;
         case WXK_DOWN:        keycode = kVK_DownArrow; break;
-            
+
         case WXK_HELP:        keycode = kVK_Help; break;
-            
-            
+
+
         case WXK_NUMPAD0:     keycode = kVK_ANSI_Keypad0; break;
         case WXK_NUMPAD1:     keycode = kVK_ANSI_Keypad1; break;
         case WXK_NUMPAD2:     keycode = kVK_ANSI_Keypad2; break;
@@ -579,10 +584,10 @@ CGKeyCode wxCharCodeWXToOSX(wxKeyCode code)
         case WXK_F18:         keycode = kVK_F18; break;
         case WXK_F19:         keycode = kVK_F19; break;
         case WXK_F20:         keycode = kVK_F20; break;
-            
+
         case WXK_PAGEUP:      keycode = kVK_PageUp; break;
         case WXK_PAGEDOWN:    keycode = kVK_PageDown; break;
-            
+
         case WXK_NUMPAD_DELETE:    keycode = kVK_ANSI_KeypadClear; break;
         case WXK_NUMPAD_EQUAL:     keycode = kVK_ANSI_KeypadEquals; break;
         case WXK_NUMPAD_MULTIPLY:  keycode = kVK_ANSI_KeypadMultiply; break;
@@ -590,12 +595,12 @@ CGKeyCode wxCharCodeWXToOSX(wxKeyCode code)
         case WXK_NUMPAD_SUBTRACT:  keycode = kVK_ANSI_KeypadMinus; break;
         case WXK_NUMPAD_DECIMAL:   keycode = kVK_ANSI_KeypadDecimal; break;
         case WXK_NUMPAD_DIVIDE:    keycode = kVK_ANSI_KeypadDivide; break;
-            
+
         default:
             wxLogDebug( "Unrecognised keycode %d", code );
             keycode = static_cast<CGKeyCode>(-1);
     }
-    
+
     return keycode;
 }
 
@@ -813,7 +818,7 @@ bool wxApp::MacSendCharEvent( wxWindow* focus , long keymessage , long modifiers
 void wxApp::MacCreateKeyEvent( wxKeyEvent& event, wxWindow* focus , long keymessage , long modifiers , long when , wxChar uniChar )
 {
 #if wxOSX_USE_COCOA_OR_CARBON
-    
+
     short keycode, keychar ;
 
     keychar = short(keymessage & charCodeMask);
