@@ -587,7 +587,7 @@ void wxPGProperty::Init()
 
     m_maxLen = 0; // infinite maximum length
 
-    m_flags = wxPGPropertyFlags::Property;
+    m_flags = wxPGFlags::Property;
 
     m_depth = 1;
 
@@ -639,24 +639,24 @@ void wxPGProperty::InitAfterAdded( wxPropertyGridPageState* pageState,
     // If in hideable adding mode, or if assigned parent is hideable, then
     // make this one hideable.
     if (
-         ( !parentIsRoot && parent->HasFlag(wxPGPropertyFlags::Hidden) ) ||
+         ( !parentIsRoot && parent->HasFlag(wxPGFlags::Hidden) ) ||
          ( propgrid && (propgrid->HasInternalFlag(wxPropertyGrid::wxPG_FL_ADDING_HIDEABLES)) )
        )
-        SetFlag(wxPGPropertyFlags::Hidden);
+        SetFlag(wxPGFlags::Hidden);
 
     // Set custom image flag.
     int custImgHeight = OnMeasureImage().y;
     if ( custImgHeight == wxDefaultCoord )
     {
-        SetFlag(wxPGPropertyFlags::CustomImage);
+        SetFlag(wxPGFlags::CustomImage);
     }
 
     if ( propgrid && (propgrid->HasFlag(wxPG_LIMITED_EDITING)) )
-        SetFlag(wxPGPropertyFlags::NoEditor);
+        SetFlag(wxPGFlags::NoEditor);
 
     // Make sure parent has some parental flags
-    if ( !parent->HasFlag(wxPGPropertyFlags::ParentalFlags) )
-        parent->SetParentalType(wxPGPropertyFlags::MiscParent);
+    if ( !parent->HasFlag(wxPGFlags::ParentalFlags) )
+        parent->SetParentalType(wxPGFlags::MiscParent);
 
     if ( !IsCategory() )
     {
@@ -712,14 +712,14 @@ void wxPGProperty::InitAfterAdded( wxPropertyGridPageState* pageState,
     if ( HasAnyChild() )
     {
         // Check parental flags
-        wxASSERT_MSG( ((m_flags & wxPGPropertyFlags::ParentalFlags) ==
-                            wxPGPropertyFlags::Aggregate) ||
-                      ((m_flags & wxPGPropertyFlags::ParentalFlags) ==
-                            wxPGPropertyFlags::MiscParent),
+        wxASSERT_MSG( ((m_flags & wxPGFlags::ParentalFlags) ==
+                            wxPGFlags::Aggregate) ||
+                      ((m_flags & wxPGFlags::ParentalFlags) ==
+                            wxPGFlags::MiscParent),
                       wxS("wxPGProperty parental flags set incorrectly at ")
                       wxS("this time") );
 
-        if ( HasFlag(wxPGPropertyFlags::Aggregate) )
+        if ( HasFlag(wxPGFlags::Aggregate) )
         {
             // Properties with private children are not expanded by default.
             SetExpanded(false);
@@ -739,7 +739,7 @@ void wxPGProperty::InitAfterAdded( wxPropertyGridPageState* pageState,
         }
 
         if ( propgrid && propgrid->HasExtraStyle(wxPG_EX_AUTO_UNSPECIFIED_VALUES) )
-            SetFlagRecursively(wxPGPropertyFlags::AutoUnspecified, true);
+            SetFlagRecursively(wxPGFlags::AutoUnspecified, true);
     }
 }
 
@@ -1047,7 +1047,7 @@ void wxPGProperty::DoGenerateComposedValue( wxString& text,
         if ( !childValue.IsNull() )
         {
             if ( overridesLeft &&
-                 curChild->HasFlag(wxPGPropertyFlags::ComposedValue) &&
+                 curChild->HasFlag(wxPGFlags::ComposedValue) &&
                  childValue.IsType(wxPG_VARIANT_TYPE_LIST) )
             {
                 wxVariantList& childList = childValue.GetList();
@@ -1309,8 +1309,8 @@ bool wxPGProperty::StringToValue( wxVariant& v, const wxString& text, wxPGPropVa
 
                     // Add only if editable or setting programmatically
                     if ( !!(flags & wxPGPropValFormatFlags::ProgrammaticValue) ||
-                         (!child->HasFlag(wxPGPropertyFlags::Disabled) &&
-                          !child->HasFlag(wxPGPropertyFlags::ReadOnly)) )
+                         (!child->HasFlag(wxPGFlags::Disabled) &&
+                          !child->HasFlag(wxPGFlags::ReadOnly)) )
                     {
                         if ( len > 0 )
                         {
@@ -1394,8 +1394,8 @@ bool wxPGProperty::StringToValue( wxVariant& v, const wxString& text, wxPGPropVa
                     wxVariant variant(oldChildValue);
 
                     if ( !!(flags & wxPGPropValFormatFlags::ProgrammaticValue) ||
-                         (!child->HasFlag(wxPGPropertyFlags::Disabled) &&
-                          !child->HasFlag(wxPGPropertyFlags::ReadOnly)) )
+                         (!child->HasFlag(wxPGFlags::Disabled) &&
+                          !child->HasFlag(wxPGFlags::ReadOnly)) )
                     {
                         wxString childName = child->GetBaseName();
 
@@ -1578,7 +1578,7 @@ void wxPGProperty::SetValue( wxVariant value, wxVariant* pList, wxPGSetValueFlag
         {
             //
             // However, situation is different for composed string properties
-            if ( HasFlag(wxPGPropertyFlags::ComposedValue) )
+            if ( HasFlag(wxPGFlags::ComposedValue) )
             {
                 tempListVariant = value;
                 pList = &tempListVariant;
@@ -1590,7 +1590,7 @@ void wxPGProperty::SetValue( wxVariant value, wxVariant* pList, wxPGSetValueFlag
             //wxLogDebug(wxS(">> %s.SetValue() adapted list value to type '%s'"),GetName(),value.GetType());
         }
 
-        if ( HasFlag(wxPGPropertyFlags::Aggregate) )
+        if ( HasFlag(wxPGFlags::Aggregate) )
             flags |= wxPGSetValueFlags::Aggregated;
 
         if ( pList && !pList->IsNull() )
@@ -1615,7 +1615,7 @@ void wxPGProperty::SetValue( wxVariant value, wxVariant* pList, wxPGSetValueFlag
                     //wxLogDebug(wxS("%i: child = %s, childValue.GetType()=%s"),i,child->GetBaseName(),childValue.GetType());
                     if ( childValue.IsType(wxPG_VARIANT_TYPE_LIST) )
                     {
-                        if ( child->HasFlag(wxPGPropertyFlags::Aggregate) && !(flags & wxPGSetValueFlags::Aggregated) )
+                        if ( child->HasFlag(wxPGFlags::Aggregate) && !(flags & wxPGSetValueFlags::Aggregated) )
                         {
                             wxVariant listRefCopy = childValue;
                             child->SetValue(childValue, &listRefCopy, flags| wxPGSetValueFlags::FromParent);
@@ -1630,10 +1630,10 @@ void wxPGProperty::SetValue( wxVariant value, wxVariant* pList, wxPGSetValueFlag
                     {
                         // For aggregate properties, we will trust RefreshChildren()
                         // to update child values.
-                        if ( !HasFlag(wxPGPropertyFlags::Aggregate) )
+                        if ( !HasFlag(wxPGFlags::Aggregate) )
                             child->SetValue(childValue, nullptr, flags| wxPGSetValueFlags::FromParent);
                         if ( !!(flags & wxPGSetValueFlags::ByUser) )
-                            child->SetFlag(wxPGPropertyFlags::Modified);
+                            child->SetFlag(wxPGFlags::Modified);
                     }
                 }
                 i++;
@@ -1653,9 +1653,9 @@ void wxPGProperty::SetValue( wxVariant value, wxVariant* pList, wxPGSetValueFlag
         }
 
         if ( !!(flags & wxPGSetValueFlags::ByUser) )
-            SetFlag(wxPGPropertyFlags::Modified);
+            SetFlag(wxPGFlags::Modified);
 
-        if ( HasFlag(wxPGPropertyFlags::Aggregate) )
+        if ( HasFlag(wxPGFlags::Aggregate) )
             RefreshChildren();
     }
     else
@@ -1710,7 +1710,7 @@ void wxPGProperty::SetValueInEvent( const wxVariant& value ) const
     GetGrid()->ValueChangeInEvent(value);
 }
 
-void wxPGProperty::SetFlagRecursively( wxPGPropertyFlags flag, bool set )
+void wxPGProperty::SetFlagRecursively( wxPGFlags flag, bool set )
 {
     ChangeFlag(flag, set);
 
@@ -1785,7 +1785,7 @@ void wxPGProperty::Enable( bool enable )
 
 void wxPGProperty::DoEnable( bool enable )
 {
-    ChangeFlag(wxPGPropertyFlags::Disabled, !enable);
+    ChangeFlag(wxPGFlags::Disabled, !enable);
 
     // Apply same to sub-properties as well
     for ( wxPGProperty* child : m_children )
@@ -1824,7 +1824,7 @@ void wxPGProperty::AdaptiveSetCell( unsigned int firstCol,
                                     const wxPGCell& cell,
                                     const wxPGCell& srcData,
                                     wxPGCellData* unmodCellData,
-                                    wxPGPropertyFlags ignoreWithFlags,
+                                    wxPGFlags ignoreWithFlags,
                                     bool recursively )
 {
     //
@@ -1866,7 +1866,7 @@ void wxPGProperty::AdaptiveSetCell( unsigned int firstCol,
     }
 }
 
-void wxPGProperty::ClearCells(wxPGPropertyFlags ignoreWithFlags, bool recursively)
+void wxPGProperty::ClearCells(wxPGFlags ignoreWithFlags, bool recursively)
 {
     if ( !(m_flags & ignoreWithFlags) && !IsRoot() )
     {
@@ -1937,7 +1937,7 @@ void wxPGProperty::SetBackgroundColour(const wxColour& colour, wxPGPropertyValue
                      newCell,
                      srcCell,
                      firstCellData,
-                     recursively ? wxPGPropertyFlags::Category : wxPGPropertyFlags::Null,
+                     recursively ? wxPGFlags::Category : wxPGFlags::Null,
                      recursively );
 }
 
@@ -1972,7 +1972,7 @@ void wxPGProperty::SetTextColour(const wxColour& colour, wxPGPropertyValuesFlags
                      newCell,
                      srcCell,
                      firstCellData,
-                     recursively ? wxPGPropertyFlags::Category : wxPGPropertyFlags::Null,
+                     recursively ? wxPGFlags::Category : wxPGFlags::Null,
                      recursively );
 }
 
@@ -1993,7 +1993,7 @@ void wxPGProperty::SetDefaultColours(wxPGPropertyValuesFlags flags)
         }
     }
 
-    ClearCells(recursively ? wxPGPropertyFlags::Category : wxPGPropertyFlags::Null,
+    ClearCells(recursively ? wxPGFlags::Category : wxPGFlags::Null,
                recursively);
 }
 
@@ -2082,18 +2082,18 @@ wxVariant wxPGProperty::GetAttributesAsList() const
 
 // Utility flags are excluded.
 // Store the literals in the internal representation for better performance.
-static const std::array<std::pair<wxPGPropertyFlags, const wxStringCharType*>, 4> gs_propFlagToString
+static const std::array<std::pair<wxPGFlags, const wxStringCharType*>, 4> gs_propFlagToString
 { {
-  { wxPGPropertyFlags::Disabled,  wxS("DISABLED")  },
-  { wxPGPropertyFlags::Hidden,    wxS("HIDDEN")    },
-  { wxPGPropertyFlags::NoEditor,  wxS("NOEDITOR")  },
-  { wxPGPropertyFlags::Collapsed, wxS("COLLAPSED") }
+  { wxPGFlags::Disabled,  wxS("DISABLED")  },
+  { wxPGFlags::Hidden,    wxS("HIDDEN")    },
+  { wxPGFlags::NoEditor,  wxS("NOEDITOR")  },
+  { wxPGFlags::Collapsed, wxS("COLLAPSED") }
 } };
 
-wxString wxPGProperty::GetFlagsAsString(wxPGPropertyFlags flagsMask) const
+wxString wxPGProperty::GetFlagsAsString(wxPGFlags flagsMask) const
 {
     wxString s;
-    const wxPGPropertyFlags relevantFlags = m_flags & flagsMask & wxPGPropertyFlags::StringStoredFlags;
+    const wxPGFlags relevantFlags = m_flags & flagsMask & wxPGFlags::StringStoredFlags;
 
     for ( auto& item : gs_propFlagToString )
     {
@@ -2112,7 +2112,7 @@ wxString wxPGProperty::GetFlagsAsString(wxPGPropertyFlags flagsMask) const
 
 void wxPGProperty::SetFlagsFromString( const wxString& str )
 {
-    wxPGPropertyFlags flags = wxPGPropertyFlags::Null;
+    wxPGFlags flags = wxPGFlags::Null;
 
     WX_PG_TOKENIZER1_BEGIN(str, wxS('|'))
         for ( auto& item : gs_propFlagToString )
@@ -2125,7 +2125,7 @@ void wxPGProperty::SetFlagsFromString( const wxString& str )
         }
     WX_PG_TOKENIZER1_END()
 
-    m_flags = (m_flags & ~wxPGPropertyFlags::StringStoredFlags) | flags;
+    m_flags = (m_flags & ~wxPGFlags::StringStoredFlags) | flags;
 }
 
 wxValidator* wxPGProperty::DoGetValidator() const
@@ -2306,7 +2306,7 @@ bool wxPGProperty::Hide( bool hide, wxPGPropertyValuesFlags flags )
 
 bool wxPGProperty::DoHide( bool hide, wxPGPropertyValuesFlags flags )
 {
-    ChangeFlag(wxPGPropertyFlags::Hidden, hide);
+    ChangeFlag(wxPGFlags::Hidden, hide);
 
     if ( !!(flags & wxPGPropertyValuesFlags::Recurse) )
     {
@@ -2321,7 +2321,7 @@ bool wxPGProperty::HasVisibleChildren() const
 {
     for ( wxPGProperty* child : m_children )
     {
-        if ( !child->HasFlag(wxPGPropertyFlags::Hidden) )
+        if ( !child->HasFlag(wxPGFlags::Hidden) )
             return true;
     }
 
@@ -2351,12 +2351,12 @@ void wxPGProperty::SetValueImage( const wxBitmapBundle& bmp )
     if ( bmp.IsOk() )
     {
         m_valueBitmapBundle = bmp;
-        m_flags |= wxPGPropertyFlags::CustomImage;
+        m_flags |= wxPGFlags::CustomImage;
     }
     else
     {
         m_valueBitmapBundle = wxBitmapBundle();
-        m_flags &= ~(wxPGPropertyFlags::CustomImage);
+        m_flags &= ~(wxPGFlags::CustomImage);
     }
 }
 
@@ -2389,12 +2389,12 @@ const wxPGProperty* wxPGProperty::GetLastVisibleSubItem() const
 
 bool wxPGProperty::IsVisible() const
 {
-    if ( HasFlag(wxPGPropertyFlags::Hidden) )
+    if ( HasFlag(wxPGFlags::Hidden) )
         return false;
 
     for (const wxPGProperty* parent = GetParent(); parent != nullptr; parent = parent->GetParent() )
     {
-        if ( !parent->IsExpanded() || parent->HasFlag(wxPGPropertyFlags::Hidden) )
+        if ( !parent->IsExpanded() || parent->HasFlag(wxPGFlags::Hidden) )
             return false;
     }
 
@@ -2470,17 +2470,17 @@ void wxPGProperty::DoPreAddChild( int index, wxPGProperty* prop )
 
     int custImgHeight = prop->OnMeasureImage().y;
     if ( custImgHeight == wxDefaultCoord /*|| custImgHeight > 1*/ )
-        prop->m_flags |= wxPGPropertyFlags::CustomImage;
+        prop->m_flags |= wxPGFlags::CustomImage;
 
     prop->m_parent = this;
 }
 
 void wxPGProperty::AddPrivateChild( wxPGProperty* prop )
 {
-    if ( !(m_flags & wxPGPropertyFlags::ParentalFlags) )
-        SetParentalType(wxPGPropertyFlags::Aggregate);
+    if ( !(m_flags & wxPGFlags::ParentalFlags) )
+        SetParentalType(wxPGFlags::Aggregate);
 
-    wxASSERT_MSG( (m_flags & wxPGPropertyFlags::ParentalFlags) == wxPGPropertyFlags::Aggregate,
+    wxASSERT_MSG( (m_flags & wxPGFlags::ParentalFlags) == wxPGFlags::Aggregate,
                   wxS("Do not mix up AddPrivateChild() calls with other ")
                   wxS("property adders.") );
 
@@ -2499,10 +2499,10 @@ wxPGProperty* wxPGProperty::InsertChild( int index,
     }
     else
     {
-        if ( !(m_flags & wxPGPropertyFlags::ParentalFlags) )
-            SetParentalType(wxPGPropertyFlags::MiscParent);
+        if ( !(m_flags & wxPGFlags::ParentalFlags) )
+            SetParentalType(wxPGFlags::MiscParent);
 
-        wxASSERT_MSG( (m_flags & wxPGPropertyFlags::ParentalFlags) == wxPGPropertyFlags::MiscParent,
+        wxASSERT_MSG( (m_flags & wxPGFlags::ParentalFlags) == wxPGFlags::MiscParent,
                       wxS("Do not mix up AddPrivateChild() calls with other ")
                       wxS("property adders.") );
 
@@ -2555,7 +2555,7 @@ void wxPGProperty::AdaptListToValue( wxVariant& list, wxVariant* value ) const
 
     // Don't fully update aggregate properties unless all children have
     // specified value
-    if ( HasFlag(wxPGPropertyFlags::Aggregate) )
+    if ( HasFlag(wxPGFlags::Aggregate) )
         allChildrenSpecified = AreAllChildrenSpecified(&list);
     else
         allChildrenSpecified = true;
@@ -2666,7 +2666,7 @@ int wxPGProperty::GetChildrenHeight( int lh, int iMax ) const
     {
         wxPGProperty* pwc = Item(i);
 
-        if ( !pwc->HasFlag(wxPGPropertyFlags::Hidden) )
+        if ( !pwc->HasFlag(wxPGFlags::Hidden) )
         {
             if ( !pwc->IsExpanded() ||
                  !pwc->HasAnyChild() )
@@ -2694,7 +2694,7 @@ wxPGProperty* wxPGProperty::GetItemAtY( unsigned int y,
 
     for ( wxPGProperty* pwc : m_children )
     {
-        if ( !pwc->HasFlag(wxPGPropertyFlags::Hidden) )
+        if ( !pwc->HasFlag(wxPGFlags::Hidden) )
         {
             // Found?
             if ( y < iy )
@@ -2739,7 +2739,7 @@ wxPGProperty* wxPGProperty::GetItemAtY( unsigned int y,
 
 void wxPGProperty::Empty()
 {
-    if ( !HasFlag(wxPGPropertyFlags::ChildrenAreCopies) )
+    if ( !HasFlag(wxPGFlags::ChildrenAreCopies) )
     {
         for ( wxPGProperty* child : m_children )
         {
@@ -2857,7 +2857,7 @@ bool wxPGProperty::AreAllChildrenSpecified( const wxVariant* pendingList ) const
 wxPGProperty* wxPGProperty::UpdateParentValues()
 {
     wxPGProperty* parent = m_parent;
-    if ( parent && parent->HasFlag(wxPGPropertyFlags::ComposedValue) &&
+    if ( parent && parent->HasFlag(wxPGFlags::ComposedValue) &&
          !parent->IsCategory() && !parent->IsRoot() )
     {
         wxString s;
@@ -2870,10 +2870,10 @@ wxPGProperty* wxPGProperty::UpdateParentValues()
 
 bool wxPGProperty::IsTextEditable() const
 {
-    if ( HasFlag(wxPGPropertyFlags::ReadOnly) )
+    if ( HasFlag(wxPGFlags::ReadOnly) )
         return false;
 
-    if ( HasFlag(wxPGPropertyFlags::NoEditor) &&
+    if ( HasFlag(wxPGFlags::NoEditor) &&
          (HasAnyChild() ||
           wxString(GetEditorClass()->GetClassInfo()->GetClassName()).EndsWith(wxS("Button")))
        )
@@ -2925,7 +2925,7 @@ wxString wxPGProperty::GetHintText() const
 
 int wxPGProperty::GetDisplayedCommonValueCount() const
 {
-    if ( HasFlag(wxPGPropertyFlags::UsesCommonValue) )
+    if ( HasFlag(wxPGFlags::UsesCommonValue) )
     {
         wxPropertyGrid* pg = GetGrid();
         if ( pg )
@@ -2980,7 +2980,7 @@ wxPGRootProperty::wxPGRootProperty( const wxString& name )
 {
     m_name = name;
     m_label = m_name;
-    SetParentalType(wxPGPropertyFlags::Null);
+    SetParentalType(wxPGFlags::Null);
     m_depth = 0;
 }
 
@@ -2993,7 +2993,7 @@ wxPG_IMPLEMENT_PROPERTY_CLASS(wxPropertyCategory, wxPGProperty, TextCtrl)
 void wxPropertyCategory::Init()
 {
     // don't set colour - prepareadditem method should do this
-    SetParentalType(wxPGPropertyFlags::Category);
+    SetParentalType(wxPGFlags::Category);
     m_capFgColIndex = 1;
     m_textExtent = -1;
 }
